import { ɵɵdefineInjectable, ɵɵinject, Injectable, EventEmitter, Component, Output, ViewChild, Input, ViewChildren, NgModule } from '@angular/core';
import { HttpHeaders, HttpClient, HttpParams, HttpClientModule } from '@angular/common/http';
import { catchError } from 'rxjs/operators';
import { throwError } from 'rxjs/index';
import { CommonModule } from '@angular/common';
import { Validators, FormBuilder, ReactiveFormsModule, FormsModule } from '@angular/forms';
import { Router, RouterModule } from '@angular/router';
import { TranslatorService } from 'a365translator';
import { BsModalRef, BsModalService, ModalModule } from 'ngx-bootstrap/modal';
import { A365loaderService, A365loaderModule } from 'a365loader';

class QuoteService {
    constructor(http) {
        this.http = http;
        this.token = undefined; // localStorage.getItem('logIn');
        // host_name: any = 'http://preapp.assist-365.com/api';
        this.voucher = '';
        this.host_name = 'https://app.assist-365.com/api';
    }
    quote(quote_data) {
        const qtype = quote_data.qtype;
        const to = quote_data.data.quote_destino.toString();
        const to_date1 = quote_data.data.quote_date1;
        const to_date2 = quote_data.data.quote_date2;
        const pax = quote_data.data.quote_paxs.toString();
        const country_code = window.localStorage.getItem('country_code');
        const entity_id = window.localStorage.getItem('entity_id');
        let country_id = '';
        const currency_selector = document.getElementById('currency_selector');
        country_id = window.localStorage.getItem('country_id');
        if (currency_selector) {
            if (currency_selector.value) {
                country_id = currency_selector.value;
            }
        }
        const date1 = new Date(to_date1);
        const date2 = new Date(to_date2);
        const diffDays = this.getDiffDays(date1, date2);
        let totalDiffDays;
        // const diffTime = Math.abs(date2.getTime() - date1.getTime());
        // const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24));
        // console.log(date1);
        // console.log(date2);
        // console.log(diffTime);
        // console.log(diffDays);
        // let totalDiffDays = 0;
        // if (qtype == 'nomadcare') {
        //   totalDiffDays = quote_data.data.days;
        // } else {
        //   totalDiffDays = diffDays + 1;
        // }
        if (qtype == 'nomadcare') {
            totalDiffDays = quote_data.data.days;
        }
        else {
            totalDiffDays = diffDays;
        }
        const query = {
            'region_id': to,
            'country_code': country_code,
            'country_id': country_id,
            'days': totalDiffDays,
            'entity_id': entity_id,
            'to_year': date2.getUTCFullYear(),
            'insured': pax.split(',').length,
        };
        if (qtype == 'nomadcare') {
            query['qsource'] = 'nomad';
        }
        if (window.localStorage.getItem('voucher')) {
            this.voucher = window.localStorage.getItem('voucher');
            query['voucher'] = this.voucher;
        }
        let urlParameters = this.jsonToQueryString(query);
        for (let i = 0; i < query.insured; i++) {
            urlParameters += '&age[]=' + pax.split(',')[i];
            // if (parseInt(pax.split(',')[i]) > 64 && totalDiffDays > 149) {
            //   alert('Pasajeros mayores a 64 años no pueden cotizar 150 días o más, sólo hasta 149 días');
            //   throw new Error('Pasajeros mayores a 64 años no pueden cotizar 150 días o más, sólo hasta 149 días');
            // }
        }
        const month = date1.toLocaleString('es-AR', { month: 'long' });
        window.localStorage.removeItem('pQuery');
        window.localStorage.setItem('pQuery', urlParameters);
        window.localStorage.setItem('to', to);
        window.localStorage.setItem('month', month);
        window.localStorage.setItem('days', '' + totalDiffDays);
        window.localStorage.setItem('date_from', to_date1);
        window.localStorage.setItem('date_to', to_date2);
        window.localStorage.setItem('input_age', pax);
    }
    jsonToQueryString(json) {
        return '?' +
            Object.keys(json).map(function (key) {
                return encodeURIComponent(key) + '=' +
                    encodeURIComponent(json[key]);
            }).join('&');
    }
    handleError(error) {
        if (error.error instanceof ErrorEvent) {
            console.error('An error occurred:', error.error.message);
        }
        else {
            console.error(`Backend returned code ${error.status}, ` +
                `body was: ${error.error}`);
        }
        return throwError(error);
        // 'Something bad happened; please try again later.'
    }
    ;
    get(api_path, SkipInter = '0') {
        const httpOptions = {
            headers: new HttpHeaders({
                'Content-Type': 'application/json',
                'Authorization': 'Bearer ' + this.token,
                'SkipInter': SkipInter
            })
        };
        return this.http.get(this.host_name + '/' + api_path, httpOptions).pipe(catchError(this.handleError));
    }
    post(params, api_path, SkipInter = '0') {
        const httpOptions = {
            headers: new HttpHeaders({
                'Authorization': 'Bearer ' + this.token,
                'SkipInter': SkipInter
            })
        };
        return this.http.post(this.host_name + '/' + api_path, params, httpOptions).pipe(catchError(this.handleError));
    }
    getDiffDays(d1, d2) {
        let diff_in_time = d2.getTime() - d1.getTime();
        let days = diff_in_time / (1000 * 3600 * 24);
        return Math.round(days) + 1;
    }
}
QuoteService.ɵprov = ɵɵdefineInjectable({ factory: function QuoteService_Factory() { return new QuoteService(ɵɵinject(HttpClient)); }, token: QuoteService, providedIn: "root" });
QuoteService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
QuoteService.ctorParameters = () => [
    { type: HttpClient }
];

class QuoteConfig {
    constructor() {
        this.config = {
            quote_redirect: false,
            get_from_localstorage: false,
            img_path: '',
            geo_location: true,
            type: 'default',
            language: 'auto',
            market: 'auto',
            toggle_scroll: true,
            destination: { label: '', value: 0, product_id: 0 },
            minimum_quote_days: 5
        };
    }
}

class ExpressQuoteComponent {
    constructor(bsModalRef, fb, quoteService, translator) {
        this.bsModalRef = bsModalRef;
        this.fb = fb;
        this.quoteService = quoteService;
        this.translator = translator;
        this.action = new EventEmitter();
        this.closeCC = new EventEmitter();
        this.cardList = [];
        this.debitList = [];
        this.auth_code_status = false;
        this.submitted = false;
    }
    submit() {
        this.submitted = true;
        if (this.quoteB2B.invalid) {
            return;
        }
        const code = this.quoteB2B.get('auth_code').value;
        this.quoteService.get('b2b?code=' + code).subscribe((data) => {
            this.auth_code_status = data.status ? true : false;
            if (data.status) {
                localStorage.setItem('b2b_auth_code', code);
                this.bsModalRef.hide();
                this.action.emit(true);
            }
        });
    }
    close() {
        this.bsModalRef.hide();
        this.closeCC.emit();
    }
    onKeyUp(x) {
        if (x.target.value.length >= 3) {
            this.auth_code_status = true;
        }
    }
    ngOnInit() {
        this.quoteB2B = this.fb.group({
            auth_code: ['', Validators.required],
        });
    }
    ngAfterContentInit() {
        setTimeout((_) => this.translator.getContent('en', 'modal-b2b').subscribe(data => {
            this.data_content = data;
        }, error => {
            console.error('error!');
        }));
    }
}
ExpressQuoteComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-express-quote',
                template: "<div id=\"loader-modal-b2b\">\n    <form [formGroup]=\"quoteB2B\" #form=\"ngForm\" aria-labelledby=\"Dir\">\n        <div class=\"modal-body\">\n            <div class=\"modal-header-body\">\n                <div class=\"loader-placeholder\">\n                    <div class=\"loader-animation loader-text\"></div>\n                    <span class=\"title\">Ingresa tu c\u00F3digo</span>\n                </div>\n            </div>\n            <div class=\"form-row text-center\">\n                <div class=\"col col-sm-8 mx-auto\">\n                    <div class=\"form-group\">\n                        <div class=\"loader-placeholder\">\n                            <div class=\"loader-animation loader-text\"></div>\n                            <input (keyup)=\"onKeyUp($event)\" type=\"text\" class=\"text-center form-control\" formControlName=\"auth_code\">\n                        </div>\n                        <div *ngIf=\"submitted && (quoteB2B.controls.auth_code.errors)\" class=\"validate-msg\">\n                            <span *ngIf=\"quoteB2B.controls.auth_code.errors.required\">Campo requerido.</span>\n                        </div>\n                        <div class=\"validate-msg\">\n                            <span *ngIf=\"submitted && !auth_code_status\">C\u00F3digo incorrecto.</span>\n                        </div>\n                    </div>\n                </div>\n            </div>\n        </div>\n        <div class=\"modal-footer\">\n            <div class=\"loader-placeholder\">\n                <div class=\"loader-animation loader-text\"></div>\n                <button (click)=\"close()\" type=\"button\" class=\"btn-footer btn-footer-default btn-fx\">CERRAR</button>\n            </div>\n            <div class=\"loader-placeholder\">\n                <div class=\"loader-animation loader-text\"></div>\n                <button (click)=\"submit()\" type=\"submit\" class=\"btn-footer btn-footer-cta btn-fx\">ACEPTAR</button>\n            </div>\n        </div>\n    </form>\n</div>\n\n\n<!-- <div class=\"modal-header header-b2b-form\">\n    <div class=\"row text-center\">\n        <div class=\"col-12\">\n            <span class=\"modal_title\">Ingresa tu c\u00F3digo</span>\n        </div>\n    </div>\n</div>\n<div class=\"modal-body\">\n    <form [formGroup]=\"quoteB2B\" #form=\"ngForm\" aria-labelledby=\"Dir\">\n        <div class=\"form-row text-center\">\n            <div class=\"col col-sm-8 mx-auto\">\n                <div class=\"form-group\">\n                    <input (keyup)=\"onKeyUp($event)\" type=\"text\" class=\"form-control\" formControlName=\"auth_code\">\n                    <div *ngIf=\"submitted && (quoteB2B.controls.auth_code.errors)\" class=\"text-danger\">\n                        <div *ngIf=\"quoteB2B.controls.auth_code.errors.required\">Campo requerido.</div>\n                    </div>\n                    <div class=\"text-danger\">\n                        <div *ngIf=\"submitted && !auth_code_status\">C\u00F3digo incorrecto.</div>\n                    </div>\n                </div>\n            </div>\n        </div>\n    </form>\n</div>\n<div class=\"modal-footer\">\n    <button (click)=\"close()\" type=\"button\" class=\"btn-core btn-core-default\">CANCELAR</button>\n    <button (click)=\"submit()\" type=\"submit\" class=\"btn-core btn-cta-1\">ACEPTAR</button>\n</div> -->",
                styles: [""]
            },] }
];
ExpressQuoteComponent.ctorParameters = () => [
    { type: BsModalRef },
    { type: FormBuilder },
    { type: QuoteService },
    { type: TranslatorService }
];
ExpressQuoteComponent.propDecorators = {
    action: [{ type: Output }],
    closeCC: [{ type: Output }]
};

class PrecheckoutComponent {
    constructor(bsModalRef, formBuilder, translator) {
        this.bsModalRef = bsModalRef;
        this.formBuilder = formBuilder;
        this.translator = translator;
        this.action = new EventEmitter();
        this.submitted = false;
        this.title = '';
    }
    set form_validation_msg(e) {
        if (e) {
            this.refreshContent('form_validation_msg');
        }
    }
    refreshContent(target) {
        if ((this.data_content && target === 'products') || (this.data_form_validation_msg && target === 'form_validation_msg')) {
            let content;
            if (target === 'refunds') {
                content = this.data_content;
            }
            if (target === 'form_validation_msg') {
                content = this.data_form_validation_msg;
            }
            this.translator.refreshContent(content, target);
        }
    }
    send() {
        this.submitted = true;
        if (this.quoteDialogForm.invalid) {
            return;
        }
        const paxname = this.quoteDialogForm.get('paxName').value;
        const paxemail = this.quoteDialogForm.get('paxEmail').value;
        window.localStorage.setItem('paxname', paxname);
        window.localStorage.setItem('paxemail', paxemail);
        const p = true;
        this.action.emit(p);
        this.bsModalRef.hide();
    }
    close() {
        this.bsModalRef.hide();
    }
    ngOnInit() {
        this.quoteDialogForm = this.formBuilder.group({
            paxName: ['', [Validators.required, Validators.pattern('^[A-Za-zñÑáéíóúÁÉÍÓÚ ]+$')]],
            paxEmail: ['', [Validators.required, Validators.email]],
        });
    }
    ngAfterViewInit() {
        setTimeout((_) => this.translator.getContent('auto', 'products').subscribe(data => {
            this.data_content = data;
            this.translator.getContent('auto', 'form_validation_msg').subscribe(data => {
                this.data_form_validation_msg = data;
            }, error => {
                console.error('error!');
            });
        }, error => {
            console.error('error!');
        }));
    }
}
PrecheckoutComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-precheckout',
                template: "<div id=\"loader-products\">\n    <form [formGroup]=\"quoteDialogForm\" (ngSubmit)=\"send()\" #form=\"ngForm\" autocomplete=\"off\" novalidate>\n        <div id=\"loader-form_validation_msg\" class=\"modal-body\">\n            <div class=\"modal-header-body\">\n                <div class=\"loader-placeholder\">\n                    <div class=\"loader-animation loader-text\"></div>\n                    <span data-dt=\"products_modal_checkout_title\" class=\"title\">{{title}}</span>\n                </div>\n            </div>\n            <div class=\"form-row text-center\">\n                <div class=\"col col-sm-8 mx-auto\">\n                    <div class=\"form-group\">\n                        <div class=\"loader-placeholder\">\n                            <div class=\"loader-animation loader-text\"></div>\n                            <input data-dt=\"products_modal_checkout_placeholder_name\"\n                                [ngClass]=\"{'input-error': submitted && quoteDialogForm.controls.paxName.errors }\"\n                                placeholder=\"Nombre y apellido\" type=\"text\" class=\"text-center form-control\"\n                                name=\"paxName\" formControlName=\"paxName\">\n                        </div>\n                        <div class=\"validate-msg\" *ngIf=\"submitted && (quoteDialogForm.controls.paxName.errors)\">\n                            <div #form_validation_msg *ngIf=\"quoteDialogForm.controls.paxName.errors.required\"\n                                class=\"loader-placeholder\">\n                                <div class=\"loader-animation loader-text\"></div>\n                                <span data-dt=\"form_validation_msg_field_required\">Campo requerido</span>\n                            </div>\n\n                            <div #form_validation_msg *ngIf=\"quoteDialogForm.controls.paxName.errors.pattern\"\n                                class=\"loader-placeholder\">\n                                <div class=\"loader-animation loader-text\"></div>\n                                <span data-dt=\"form_validation_msg_invalid_characters\">Caracteres incorrectos</span>\n                            </div>\n                        </div>\n                    </div>\n                    <div class=\"form-group\">\n                        <div class=\"loader-placeholder\">\n                            <div class=\"loader-animation loader-text\"></div>\n                            <input data-dt=\"products_modal_checkout_placeholder_email\"\n                                [ngClass]=\"{'input-error' : submitted && quoteDialogForm.controls.paxEmail.errors }\"\n                                placeholder=\"Email\" type=\"text\" class=\"text-center form-control\"\n                                formControlName=\"paxEmail\" type=\"email\">\n                        </div>\n                        <div *ngIf=\"submitted && (quoteDialogForm.controls.paxEmail.errors)\" class=\"validate-msg\">\n                            <div #form_validation_msg class=\"loader-placeholder\"\n                                *ngIf=\"quoteDialogForm.controls.paxEmail.errors.required\">\n                                <div class=\"loader-animation loader-text\"></div>\n                                <span data-dt=\"form_validation_msg_field_required\">Campo obligatorio</span>\n                            </div>\n\n                            <div #form_validation_msg class=\"loader-placeholder\"\n                                *ngIf=\"quoteDialogForm.controls.paxEmail.errors.email\">\n                                <div class=\"loader-animation loader-text\"></div>\n                                <span data-dt=\"form_validation_msg_email_invalid\">Email incorrecto</span>\n                            </div>\n                        </div>\n                    </div>\n                </div>\n            </div>\n        </div>\n        <div class=\"modal-footer\">\n            <div class=\"loader-placeholder\">\n                <div class=\"loader-animation loader-text\"></div>\n                <button data-dt=\"products_modal_btn_close\" (click)=\"close()\" type=\"button\"\n                    class=\"btn-footer btn-footer-default btn-fx\">CERRAR</button>\n            </div>\n            <div class=\"loader-placeholder\">\n                <div class=\"loader-animation loader-text\"></div>\n                <button data-dt=\"products_modal_btn_confirm\" type=\"submit\"\n                    class=\"btn-footer btn-footer-cta btn-fx\">ACEPTAR</button>\n            </div>\n        </div>\n    </form>\n</div>",
                styles: [".modal-header{align-items:center;justify-content:center}.modal-body{padding:2rem 1.5rem 1.2rem}.modal-header-body{padding-bottom:1.2rem}.modal-header-body .title{text-align:center;font-weight:600;display:block;line-height:normal;font-size:1.1rem;color:#00698f}@media (min-width:992px){.modal-header-body .title{margin-bottom:.5rem}}.modal-header-body input.form-control{height:46px;font-size:.9rem}.modal-footer{border-top:0;display:flex;align-items:center;justify-content:center;padding:0;overflow:hidden;border-bottom-left-radius:.3rem;border-bottom-right-radius:.3rem}.modal-footer div>button{width:100%;margin:0}.modal-footer button:not(.loader-placeholder){margin:0;width:100%}.modal-footer .btn-footer{border-radius:0;border:0;outline:0;height:100%;padding:1rem 0;width:100%;font-size:.8rem;font-weight:600;transition:all .25s ease-in;cursor:pointer}.modal-footer .btn-footer.btn-footer-default{color:#999}.modal-footer .btn-footer.btn-footer-cta{background:#1ccdc9;color:#fff}.modal-footer{margin:0}.modal-footer button{text-transform:uppercase}.modal-footer div{width:100%}.modal-footer>:not(:first-child){margin:0}.modal-footer>:not(:last-child){margin:0}.validate-msg{padding:.3em 0}.validate-msg span{font-size:.75rem;color:#dc3545}"]
            },] }
];
PrecheckoutComponent.ctorParameters = () => [
    { type: BsModalRef },
    { type: FormBuilder },
    { type: TranslatorService }
];
PrecheckoutComponent.propDecorators = {
    action: [{ type: Output }],
    form_validation_msg: [{ type: ViewChild, args: ['form_validation_msg',] }]
};

/*

- minimo de dias invalidados

*/
class QuoteComponent {
    constructor(quoteService, formBuilder, router, translator, modalService, loaderService, config) {
        this.quoteService = quoteService;
        this.formBuilder = formBuilder;
        this.router = router;
        this.translator = translator;
        this.modalService = modalService;
        this.loaderService = loaderService;
        this.quote_mode = 'default';
        this.emit_quote = new EventEmitter();
        this.modal_dialog_container = false;
        this.quote_redirect = false;
        this.quote_modal = false;
        this.add_pax_btn = true;
        this.dates_data_content = [];
        this.dates_data = { months: [], days: [] };
        this.default_dates_data = {
            months: ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'],
            days: ['Domingo', 'Lunes', 'Martes', 'Miércoles', 'Jueves', 'Viernes', 'Sábado']
        };
        this.quote_data = {
            data: {
                quote_destino: 0,
                quote_date1: '',
                quote_date2: '',
                quote_paxs: [],
                days: 0,
            },
            passed: {
                quote_destino: true,
                quote_dates1: true,
                quote_dates2: true,
                paxAges: true
            }
        };
        this.quote_submit_paxs = false;
        this.generateCalendar = () => {
            let today = new Date();
            let month = today.getMonth();
            let year = today.getFullYear();
            const calendarContainer = document.querySelector('.calendar-body');
            // m <= 12
            for (let m = 0; m <= 48; m++) {
                const calendarCont = document.createElement('div');
                // calendarCont.setAttribute('class', 'calendar-month');
                //! FIX FIX FIX 
                // if ((month + 1) % 12 == 0) {
                // if ((month) % 12 === 0) {
                //   year = year + 1;
                // }
                if (month === 0) {
                    if (m != 0) {
                        year = year + 1;
                    }
                }
                let x_month = month + 1;
                this.setAttributes(calendarCont, {
                    'class': 'calendar-month col-12 col-sm-6',
                    'data-month': `${x_month}-${year}`,
                    'id': `cal-${x_month}-${year}`
                });
                let month_name = this.getMonthDay(month, 'm');
                let headerCalendar = `
            <div class='header'>
            <span data-dt="dates_data_month_${month}">${month_name}</span>
            <span>${year}</span>
            </div>
            `;
                calendarCont.insertAdjacentHTML('afterbegin', headerCalendar);
                const table = document.createElement('TABLE');
                const thead = document.createElement('thead');
                const tr_head = document.createElement('tr');
                for (let i = 0; i < 7; i++) {
                    const th = document.createElement('th');
                    let dnam = this.getMonthDay(i, 'd');
                    let dnx = dnam.substr(0, 3);
                    th.appendChild(document.createTextNode(dnx));
                    tr_head.appendChild(th);
                }
                thead.appendChild(tr_head);
                table.insertAdjacentElement('afterbegin', thead);
                let tbody = document.createElement('tbody');
                let firstDay = (new Date(year, month)).getDay();
                let daysInMonth = 32 - new Date(year, month, 32).getDate();
                let date = 1;
                for (let i = 0; i < 6; i++) {
                    let row = document.createElement("tr");
                    for (let j = 0; j < 7; j++) {
                        if (i === 0 && j < firstDay) {
                            let cell = document.createElement("td");
                            let cellText = document.createTextNode("");
                            cell.appendChild(cellText);
                            row.appendChild(cell);
                        }
                        else if (date > daysInMonth) {
                            break;
                        }
                        else {
                            let cell = document.createElement("td");
                            if (date === today.getDate() && year === today.getFullYear() && month === today.getMonth()) {
                                cell.classList.add("current-day", "selectable");
                            } // color today's date
                            let days = 364 * 2;
                            if (new Date(`${month + 1}/${date}/${year}`).getTime() > today.getTime() &&
                                new Date(`${month + 1}/${date}/${year}`).getTime() < this.sumarDias(new Date(), days).getTime()) {
                                cell.classList.add('selectable');
                            } // selecteable
                            cell.insertAdjacentHTML('afterbegin', `<div>${date}</div>`);
                            row.appendChild(cell);
                            date++;
                        }
                    }
                    tbody.appendChild(row);
                }
                table.insertAdjacentElement('beforeend', tbody);
                calendarCont.insertAdjacentElement('beforeend', table);
                let feriados = this.getFeriados(month, 2020);
                // if (feriados) {
                //   let feriados_data = '';
                //   for (const [key, value] of Object.entries(feriados)) {
                //     feriados_data += `
                //           <tr>
                //               <td><div>${key}</div></td>
                //               <td><div>${value}</div></td>
                //           </tr>
                //           `;
                //   }
                //   let calendarFooter = `
                //   <div class="calendar-month-footer">
                //       <table class="month-details">
                //       ${feriados_data}                
                //       </table>
                //   </div>`;
                //   calendarCont.insertAdjacentHTML('beforeend', calendarFooter);
                // }
                calendarContainer.insertAdjacentElement('beforeend', calendarCont);
                if (month === 11) {
                    month = 0;
                }
                else {
                    month = (month + 1) % 12;
                }
            }
            let start_date_selected = null;
            let start_date = null;
            let end_date = null;
            document.querySelectorAll('.calendar-body table td.selectable')
                .forEach(e => e.addEventListener("click", (event) => {
                const target = event.currentTarget;
                const target2 = event.target;
                if (!target.classList.contains('disabled')) {
                    let month_year = $(e).parents()[3].getAttribute('data-month');
                    let day = target2.textContent;
                    let di = document.querySelector('.di');
                    let de = document.querySelector('.de');
                    let d = parseInt(day) <= 9 ? '0' + day : day;
                    let m, y;
                    start_date_selected = `${d}-${month_year}`;
                    [d, m, y] = start_date_selected.split('-');
                    let fd = `${m}-${d}-${y}`;
                    // if (start_date && end_date && $('#selection-mode').prop("checked")) {
                    // } else {
                    if (start_date && end_date) {
                        const selector_state = $('#selection-mode').prop("checked");
                        let sd;
                        if (!selector_state) {
                            sd = 0;
                        }
                        start_date = null;
                        end_date = null;
                        this.setHeaderData(0, 0);
                        if (document.querySelector('.range-start') && document.querySelector('.range-end')) {
                            let rs = document.querySelector('.range-start');
                            let re = document.querySelector('.range-end');
                            rs.classList.remove('range-start');
                            re.classList.remove('range-end');
                        }
                        let cs = document.querySelector('.date-range-start');
                        if (cs) {
                            cs.classList.remove('date-range-start');
                        }
                        let ce = document.querySelector('.date-range-end');
                        if (ce) {
                            ce.classList.remove('date-range-end');
                        }
                        const el = document.querySelector('.date-range');
                        document.querySelectorAll('.date-range')
                            .forEach(el => el.classList.remove('date-range'));
                        this.cleanInitRange();
                    }
                    let sd_data = $('input[name="sd_date"]').val();
                    if (sd_data.length === 0) {
                        // console.log('start_date no declarada');
                        target.classList.add('date-range-start');
                        // target.classList.add('range-start');
                        start_date = new Date(fd.toString().replace(/-/g, '/'));
                        this.setHeaderData(fd, 0);
                        this.setInitEndDate(new Date(fd.toString().replace(/-/g, '/')));
                        $('#selection-mode').prop("disabled", false);
                        // anual 365
                        if ($('#selection-mode').prop("checked")) {
                            // console.log('quote_365 running...');
                            this.quote_365();
                        }
                    }
                    else {
                        const date_check = new Date(fd);
                        // fecha menor
                        if (date_check.getTime() < start_date.getTime()) {
                            this.cleanInitRange();
                            this.setInitEndDate(new Date(fd));
                            start_date = date_check;
                            this.setHeaderData(fd, 0);
                            let cs = document.querySelector('.date-range-start');
                            cs.classList.remove('date-range-start');
                            $('td.range-start').removeClass('range-start');
                            target.classList.add('date-range-start');
                            // target.classList.add('range-start');
                        }
                        else if (date_check.getTime() === start_date.getTime()) {
                            // misma fecha
                            $('.de').removeClass('block-active');
                            $('#selection-mode').prop("disabled", false);
                            start_date = null;
                            end_date = null;
                            let cs = document.querySelector('.date-range-start');
                            cs.classList.remove('date-range-start');
                            $('td.range-start').removeClass('range-start');
                            this.cleanInitRange();
                            this.setHeaderData(0, 0);
                            $('.month-disabled').removeClass('month-disabled');
                        }
                        else {
                            target.classList.add('date-range-end');
                            end_date = new Date(fd.toString().replace(/-/g, '/'));
                            d = start_date.getDate();
                            m = start_date.getMonth() + 1;
                            y = start_date.getFullYear();
                            const sd = `${m}-${d}-${y}`;
                            this.setHeaderData(sd, fd);
                            const de_content = this.getMonthDay(new Date(fd.toString().replace(/-/g, '/')), 'f');
                            de.lastElementChild.textContent = de_content.toString();
                            this.setDateRange(start_date, end_date);
                            document.querySelector('.date-range-start').classList.add('range-start');
                            document.querySelector('.date-range-end').classList.add('range-end');
                            $('#selection-mode').prop("disabled", !$('#selection-mode').prop("checked"));
                            $('td.disabled').removeClass('disabled').addClass('selectable');
                        }
                    }
                }
                ;
            }));
            if (this.quote_data.data.quote_date1.length > 1 && this.quote_data.data.quote_date2.length > 1) {
                let cr = this.getMonthDay(new Date(this.quote_data.data.quote_date1), 'x');
                let ce = this.getMonthDay(new Date(this.quote_data.data.quote_date2), 'x');
                const sd_elem_1 = `cal-${cr[1] + 1}-${cr[2]}`;
                const sd_elem_2 = `cal-${ce[1] + 1}-${ce[2]}`;
                const sd_elm = $("#" + sd_elem_1 + " table tbody td.selectable div").filter(function () {
                    return $(this).text() === `${cr[0]}`;
                }).trigger('click').trigger('touchstart');
                const sd_elm2 = $("#" + sd_elem_2 + " table tbody td.selectable div").filter(function () {
                    return $(this).text() === `${ce[0]}`;
                }).trigger('click').trigger('touchstart');
                document.getElementById(sd_elem_1).scrollIntoView({
                    behavior: 'smooth'
                });
            }
            else {
                let btn_submit = document.getElementById('quote_submit_dates');
                btn_submit.disabled = true;
            }
            if (this.quote_settings.annual365) {
                const selection_mode = document.getElementById('selection-mode');
                selection_mode.addEventListener('click', event => {
                    this.quote_365();
                });
            }
        };
        this.quote_settings = config.config;
        this.quote_redirect = config.config.quote_redirect;
        this.img_path = config.config.img_path;
        this.img_path = this.img_path.length >= 1 ? this.img_path + '/assets/img' : 'assets/img';
        this.quote_settings.start = false;
        this.quote_settings['annual365'] = true;
        const urlParams = window.location.search;
        const urlQuery = new URLSearchParams(urlParams);
        this.external_source_data = urlQuery;
        if (window.localStorage.getItem('destination')) {
            window.localStorage.removeItem('destination');
        }
        if (this.quote_settings.market == 'auto') {
            const hostname_markets = [
                { hostname: 'assist-365.com', market: 'global' },
                { hostname: 'assist-365.com.br', market: 'br' }
            ];
            const pre_market = hostname_markets.filter(market => market.hostname == window.location.hostname);
            this.quote_settings['market'] = pre_market.length != 0 ? pre_market[0]['market'] : 'global';
        }
        if (this.quote_settings.type === 'auto') {
            this.quote_settings.type = window.localStorage.getItem('quote_type');
        }
        this.quote_modal_data = {
            titles: { pt: '', mt: '' }
        };
        if (this.quote_settings['market'] == 'global') {
            this.geo_url = this.router.url.split('/')[1].substring(0, 2);
            // console.log('set geo_url -> ', this.geo_url);
        }
        else {
            this.geo_url = '';
        }
        //*******************
        //^   B R A Z I L   
        //*******************
        if (this.quote_settings['market'] == 'br') {
            console.warn('market@BR');
            this.quoteService.get('geolocation').subscribe((data) => {
                //*******************
                //^   WIP  B R A Z I L  (origin_country)
                //*******************
                this.origin_country = data.country_id;
                // console.log('origin_country ----', this.origin_country);
                //! FORCE TEST
                // this.origin_country = 155;
                if (this.origin_country != 155) {
                    this.quoteService.get('geolocation').subscribe((data) => {
                        window.localStorage.setItem('country_code', data.country);
                        window.localStorage.setItem('country_name', data.country_name);
                        window.localStorage.setItem('country_id', data.country_id);
                        window.localStorage.setItem('entity_id', data.entity);
                        window.localStorage.setItem('seller_id', data.seller);
                        window.localStorage.setItem('currency_symbol', data.currency_symbol);
                    });
                }
            });
        }
        if (this.router.url.split('/').length >= 2) {
            switch (this.router.url.split('/')[2]) {
                case 'cotizador-express-b2b':
                    this.quote_settings['mode'] = 'b2b';
                    break;
                default:
                    this.quote_settings['mode'] = 'b2c';
            }
        }
        else {
            this.quote_settings['mode'] = 'b2c';
        }
        this.quoteForm = this.formBuilder.group({
            quote_destino: ['', Validators.required],
            quote_dates1: ['', Validators.required],
            quote_dates2: ['', Validators.required],
            paxAges: ['', Validators.required]
        });
        this.quote_submit = {
            'dates': false
        };
        this.quote_destinos = [
            { val: 10, name: 'Europa', destination_code: 'eu' },
            { val: 5, name: 'Sudamerica y Caribe', destination_code: 'sc' },
            { val: 16, name: 'Norteamerica', destination_code: 'na' },
            { val: 9, name: 'Asia', destination_code: 'as' },
            { val: 2, name: 'Oceanía', destination_code: 'oc' },
            { val: 6, name: 'Africa', destination_code: 'af' },
            { val: 17, name: 'Varios destinos', destination_code: 'vd' },
        ];
        // FILTER Destinos for Market
        const market_settings = [
            { market: 'br', destinos: [5, 10, 16, 17], annual365: false }
        ];
        if (this.quote_settings['market'] != 'global') {
            const current_market = market_settings.filter(destinos => destinos.market == this.quote_settings['market'])[0];
            if (current_market) {
                this.quote_destinos = this.quote_destinos.filter(destino => current_market['destinos'].includes(destino.val));
                this.quote_settings['annual365'] = current_market['annual365'];
                // console.log(current_market);
            }
        }
        if (this.quote_settings.hasOwnProperty('destination')) {
            if (this.quote_settings['destination'].hasOwnProperty('value')) {
                this.quoteForm.patchValue({
                    quote_destino: this.quote_settings.destination.label
                });
                this.quote_data.data.quote_destino = this.quote_settings.destination.value;
                this.quote_data.passed.quote_destino = true;
            }
        }
    }
    set dyn_data_quote_destination(e) {
        if (e) {
            this.translator.refreshContent(this.data_content, 'quote');
        }
    }
    set dyn_data_quote_dates(e) {
        if (e) {
            this.translator.refreshContent(this.data_content, 'quote_data');
        }
    }
    set dyn_data_quote_paxs(e) {
        if (e) {
            this.translator.refreshContent(this.data_content, 'quote');
        }
    }
    set pax_age_input(e) {
        if (e) {
            this.translator.refreshContent(this.data_content, 'quote');
        }
    }
    set quote_init(e) {
        if (e) {
            this.initQuote();
        }
    }
    emitQuote(id) {
        this.emit_quote.emit(id);
    }
    getMonthDay(v, t) {
        if (this.dates_data_content.length != 0) {
            if (this.dates_data.months.length === 0 && this.dates_data.days.length === 0) {
                this.dates_data_content.filter(elem => {
                    let area = elem.area.substring(11, elem.area.length).split('_');
                    switch (area[0]) {
                        case 'month':
                            this.dates_data.months[parseInt(area[1])] = elem.text;
                            break;
                        case 'day':
                            this.dates_data.days[parseInt(area[1])] = elem.text;
                            break;
                    }
                });
            }
        }
        else {
            this.dates_data = this.default_dates_data;
        }
        const months = ["enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto", "septiembre", "octubre", "noviembre", "diciembre"];
        const days_name = ['Domingo', 'Lunes', 'Martes', 'Miercoles', 'Jueves', 'Viernes', 'Sabado'];
        let fd;
        if (t === 'f' || t === 'x') {
            fd = new Date(v);
        }
        let d, m, y, dn;
        switch (t) {
            case 'm':
                return this.dates_data.months[v];
            case 'd':
                return this.dates_data.days[v];
            case 'f':
                d = fd.getDate();
                m = fd.getMonth();
                y = fd.getFullYear();
                dn = fd.getDay();
                return `${this.dates_data.days[dn].substr(0, 3)}, ${d} ${this.dates_data.months[m].substr(0, 3)} ${y}`;
            case 'x':
                d = fd.getDate();
                m = fd.getMonth();
                y = fd.getFullYear();
                return [d, m, y];
        }
    }
    quote_365() {
        const _self = $('#selection-mode');
        let sd = new Date($('input[name="sd_date"]').val());
        if (_self.prop("checked")) {
            let rs = $('.date-range-start');
            rs.next().removeClass('disabled');
            rs.next().next().removeClass('disabled');
            let ed = this.sumarDias(new Date($('input[name="sd_date"]').val()), 364);
            const dateRange = {
                start_date: {
                    date: sd.getDate(),
                    month: sd.getMonth() + 1,
                    year: sd.getFullYear()
                },
                end_date: {
                    date: ed.getDate(),
                    month: ed.getMonth() + 1,
                    year: ed.getFullYear()
                },
                range_dates: this.getDiffDays(sd, ed)
            };
            const sd_data = `${dateRange.start_date.month}-${dateRange.start_date.year}`;
            const ed_data = `${dateRange.end_date.month}-${dateRange.end_date.year}`;
            // set end date
            let ed_elem = $('.calendar-month[data-month="' + ed_data + '"] table tbody td:contains(' + dateRange.end_date.date + ')')
                .filter(function () {
                return $(this).text() === dateRange.end_date.date.toString();
            });
            ;
            ed_elem.trigger('click').trigger('touchstart');
            this.setHeaderData(sd, ed);
        }
        else {
            $('.calendar-month').removeClass('month-disabled');
            this.setHeaderData(0, 0);
            if (document.querySelector('.range-start') && document.querySelector('.range-end')) {
                let rs = document.querySelector('.range-start');
                let re = document.querySelector('.range-end');
                rs.classList.remove('range-start');
                re.classList.remove('range-end');
            }
            let cs = document.querySelector('.date-range-start');
            if (cs) {
                cs.classList.remove('date-range-start');
            }
            let ce = document.querySelector('.date-range-end');
            if (ce) {
                ce.classList.remove('date-range-end');
            }
            const el = document.querySelector('.date-range');
            document.querySelectorAll('.date-range')
                .forEach(el => el.classList.remove('date-range'));
            this.cleanInitRange();
        }
    }
    getDiffMonths(d2, d1) {
        return d1.getMonth() - d2.getMonth() +
            (12 * (d1.getFullYear() - d2.getFullYear()));
    }
    getDaysInMonth(m, y) {
        return 32 - new Date(y, m, 32).getDate();
    }
    setRangeDates(m, y, sd_elem, days) {
        for (let i = 0; i < days; i++) {
            if (!sd_elem.classList.contains('date-range-start') && !sd_elem.classList.contains('date-range-end')) {
                sd_elem.classList.add('date-range');
            }
            if (sd_elem.nextSibling) {
                sd_elem = sd_elem.nextSibling;
            }
            else {
                let x = parseInt(sd_elem.textContent) + 1;
                let data_month = `${m}-${y}`;
                let z = $('.calendar-month[data-month="' + data_month + '"] table tbody td:contains(' + x + ')');
                sd_elem = z[0];
            }
        }
    }
    setDateRange(sd, ed) {
        const p_d1 = this.getMonthDay(sd, 'x');
        const p_d2 = this.getMonthDay(ed, 'x');
        let d1 = new Date(`${p_d1[1] + 1}/${p_d1[0]}/${p_d1[2]}`);
        let d2 = new Date(`${p_d2[1] + 1}/${p_d2[0]}/${p_d2[2]}`);
        const total_days = this.getDiffDays(d1, d2);
        const dateRange = {
            start_date: {
                date: sd.getDate(),
                month: sd.getMonth(),
                year: sd.getFullYear()
            },
            end_date: {
                date: ed.getDate(),
                month: ed.getMonth(),
                year: ed.getFullYear()
            },
            range_dates: this.getDiffDays(d1, d2)
        };
        // mismo mes/año
        const range_months = this.getDiffMonths(sd, ed);
        if (sd.getMonth() == ed.getMonth() && sd.getFullYear() == ed.getFullYear()) {
            let sd_elem = document.querySelector('.date-range-start');
            let days = dateRange.end_date.date - dateRange.start_date.date;
            this.setRangeDates(dateRange.start_date.month + 1, dateRange.start_date.year, sd_elem, days);
        }
        else {
            if (sd.getFullYear() < ed.getFullYear()) {
                let sd_elem = document.querySelector('.date-range-start');
                let daysInMonth = this.getDaysInMonth(sd.getMonth(), sd.getFullYear());
                let days = daysInMonth - dateRange['start_date']['date'] + 1;
                let queueDays = total_days - days;
                let nMonth = dateRange.start_date.month + 1;
                this.setRangeDates(nMonth, dateRange.start_date.year, sd_elem, days);
                let setMonth = dateRange.start_date.month;
                let setYear = dateRange.start_date.year;
                for (let m = 1; m <= range_months; m++) {
                    if (setMonth + 1 + m === 13) {
                        setMonth = -m;
                        setYear = setYear + 1;
                        nMonth = setMonth - 1;
                    }
                    let data_month = `${setMonth + 1 + m}-${setYear}`;
                    nMonth = setMonth;
                    daysInMonth = this.getDaysInMonth(nMonth + m, setYear);
                    if (queueDays <= daysInMonth) {
                        // queue days menor al mes
                        let x = 1;
                        let z = $('.calendar-month[data-month="' + data_month + '"] table tbody td:contains(' + x + ')');
                        sd_elem = z[0];
                        this.setRangeDates(setMonth + 1 + m, setYear, sd_elem, queueDays);
                    }
                    else {
                        // console.error('mas dias en queue');
                        let x = 1;
                        let z = $('.calendar-month[data-month="' + data_month + '"] table tbody td:contains(' + x + ')');
                        sd_elem = z[0];
                        this.setRangeDates(setMonth + 1 + m, setYear, sd_elem, daysInMonth);
                        queueDays = queueDays - daysInMonth;
                    }
                }
            }
            else {
                let sd_elem = document.querySelector('.date-range-start');
                if (range_months >= 1) {
                    let daysInMonth = this.getDaysInMonth(sd.getMonth(), sd.getFullYear());
                    let days = daysInMonth - dateRange['start_date']['date'] + 1;
                    let queueDays = total_days - days;
                    let nMonth = dateRange.start_date.month + 1;
                    this.setRangeDates(nMonth, dateRange.start_date.year, sd_elem, days);
                    for (let m = 1; m <= range_months; m++) {
                        nMonth = dateRange.start_date.month + 1;
                        let data_month = `${dateRange['start_date']['month'] + 1 + m}-${dateRange['start_date']['year']}`;
                        nMonth = dateRange['start_date']['month'];
                        daysInMonth = this.getDaysInMonth(nMonth + m, dateRange['start_date']['year']);
                        if (queueDays <= daysInMonth) {
                            // queue days menor al mes
                            let x = 1;
                            let z = $('.calendar-month[data-month="' + data_month + '"] table tbody td:contains(' + x + ')');
                            sd_elem = z[0];
                            this.setRangeDates(dateRange['start_date']['month'] + 1 + m, dateRange['start_date']['year'], sd_elem, queueDays);
                        }
                        else {
                            // queue days mayor al mes
                            let x = 1;
                            let z = $('.calendar-month[data-month="' + data_month + '"] table tbody td:contains(' + x + ')');
                            sd_elem = z[0];
                            this.setRangeDates(dateRange['start_date']['month'] + 1 + m, dateRange['start_date']['year'], sd_elem, daysInMonth);
                            queueDays = queueDays - daysInMonth;
                        }
                    }
                }
            }
        }
    }
    sumarDias(fecha, dias) {
        fecha.setDate(fecha.getDate() + dias);
        return fecha;
    }
    cleanInitRange() {
        // console.log('---cleanInitRange()');
        let x = document.querySelectorAll('.calendar-container table tbody tr td.selectable.disabled');
        x.forEach(function (e) {
            e.classList.remove('disabled');
            e.classList.remove('date-range');
        });
    }
    setInitEndDate(sdx) {
        // next 2 days disabled
        // minimo de dias invalidados
        const min_invalid_days = this.quote_settings.minimum_quote_days;
        if (($('#selection-mode').prop("checked") === false) || this.quote_settings.annual365 == false) {
            for (let i = 1; i < (min_invalid_days + 1); i++) {
                let dt = this.sumarDias(new Date(sdx.setDate(sdx.getDate())), i);
                let data_month = `${dt.getMonth() + 1}-${dt.getFullYear()}`;
                let x = dt.getDate();
                let t = $('.calendar-month[data-month="' + data_month + '"] table tbody td:contains(' + x + ')')
                    .filter(function () {
                    return $(this).text() === x.toString();
                });
                t[0].classList.add('disabled');
                // t[0].classList.add('date-range');
            }
        }
        let calendar_months = $('.calendar-month');
        calendar_months.removeClass('month-disabled');
        let limit_calendar = `${sdx.getMonth() + 2}-${sdx.getFullYear() + 1}`;
        let t = $('.calendar-month[data-month="' + limit_calendar + '"]');
        let s = false;
        calendar_months.each(function (index) {
            let id = $(this).attr('id');
            let init_calendar = 'cal-' + limit_calendar;
            if (id === init_calendar) {
                s = true;
                if (s) {
                    let r = $('#' + id);
                    r.addClass('month-disabled');
                }
            }
            else {
                if (s) {
                    let r = $('#' + id);
                    r.addClass('month-disabled');
                }
            }
        });
        const limit_calendar_month = `${sdx.getMonth() + 1}-${sdx.getFullYear() + 1}`;
        $('#cal-' + limit_calendar_month + ' td').each(function (idx) {
            if (parseInt($(this).text()) >= sdx.getDate()) {
                $(this).removeClass('selectable').addClass('disabled');
            }
        });
        const end_date = sdx.getDate();
        // set end date
        let ed_elem = $('.calendar-month[data-month="' + limit_calendar_month + '"] table tbody td:contains(' + end_date + ')')
            .filter(function () {
            return $(this).text() === end_date.toString();
        });
        ;
    }
    getDiffDays(d1, d2) {
        let diff_in_time = d2.getTime() - d1.getTime();
        let days = diff_in_time / (1000 * 3600 * 24);
        return Math.round(days) + 1;
    }
    setHeaderData(sd = null, ed = null) {
        let di = document.querySelector('.di');
        let de = document.querySelector('.de');
        let ch = document.querySelector('.calendar-footer-container');
        let sd_data, ed_data, td_data = '';
        let input_sd = $('input[name="sd_date"]');
        let input_ed = $('input[name="ed_date"]');
        let btn_submit = document.getElementById('quote_submit_dates');
        if (sd && ed) {
            btn_submit.disabled = false;
            td_data = `${this.getDiffDays(new Date(sd.toString().replace(/-/g, '/')), new Date(ed.toString().replace(/-/g, '/')))} `;
        }
        else {
            td_data = '';
            btn_submit.disabled = true;
        }
        if (sd) {
            sd_data = this.getMonthDay(new Date(sd.toString().replace(/-/g, '/')), 'f');
            input_sd.val(new Date(sd.toString().replace(/-/g, '/')));
            $('.di').removeClass('block-active').addClass('active-label');
        }
        else {
            sd_data = '';
            input_sd.val('');
            $('.di').addClass('block-active').removeClass('active-label');
        }
        if (ed) {
            ed_data = this.getMonthDay(new Date(ed.toString().replace(/-/g, '/')), 'f');
            input_ed.val(new Date(ed.toString().replace(/-/g, '/')));
            $('.de').removeClass('block-active').addClass('active-label');
        }
        else {
            ed_data = '';
            input_ed.val('');
            if (sd) {
                $('.de').addClass('block-active').removeClass('active-label');
            }
        }
        di.lastElementChild.textContent = sd_data;
        de.lastElementChild.textContent = ed_data;
        ch.querySelector('.quote-msg-container').textContent = td_data;
    }
    dialogB2B() {
        const config = {
            animated: true,
            keyboard: false,
            backdrop: true,
            ignoreBackdropClick: true,
        };
        const initialState = {
            d: this.quote_data,
            data_content: this.data_content
        };
        this.bsModalRef = this.modalService.show(ExpressQuoteComponent, Object.assign(config, { class: 'modal-dialog-centered' }, { initialState }));
        this.bsModalRef.content.closeBtnName = 'Seleccionar';
        this.bsModalRef.content.action.subscribe((p) => {
            if (p) {
                this.quoteService.quote(this.quote_data);
                window.location.href = `${this.geo_url}/productos`;
            }
        });
    }
    ngOnInit() {
        this.quote_selector_paxs = 10;
        this.quote_state = {
            field_dest: false,
            field_dates: false,
            field_paxs: false
        };
        // set Voucher
        this.url_param = this.getParamValueQueryString('voucher');
        if (this.url_param) {
            window.localStorage.setItem('voucher', this.url_param);
        }
        if (this.quote_settings.geo_location && this.geo_url.length == 2) {
            // GEOLOCATION
            const country_code = this.geo_url.toUpperCase();
            if (localStorage.getItem("lang") != 'br') {
                this.quoteService.get(`geolocation?flag=true&country_code=${country_code}`).subscribe((data) => {
                    window.localStorage.setItem('country_code', data.country);
                    window.localStorage.setItem('country_name', data.country_name);
                    window.localStorage.setItem('country_id', data.country_id);
                    window.localStorage.setItem('entity_id', data.entity);
                    window.localStorage.setItem('seller_id', data.seller);
                    window.localStorage.setItem('currency_symbol', data.currency_symbol);
                    this.country_code = window.localStorage.getItem('country_code');
                    if (window.localStorage.getItem('locale')) {
                        const browserLang = localStorage.getItem('locale');
                    }
                    else {
                        window.localStorage.setItem('locale', data.locale);
                    }
                });
            }
        }
        if (this.quote_settings.type) {
            this.quote_settings.start = true;
        }
    }
    selectOpt(e) {
        e.currentTarget.parentNode.parentNode.querySelectorAll('button').forEach(e => {
            if (e.classList.contains('active'))
                e.classList.remove('active');
        });
        e.currentTarget.classList.add('active');
        let q_block = e.currentTarget.parentNode.parentNode.parentNode.parentNode;
        let q_source = e.currentTarget.parentNode.parentNode.getAttribute('data-source');
        let q_value = q_block.querySelector('.quote-value').getElementsByTagName('span')[0];
        if (q_value.classList.contains('qv-error')) {
            q_value.classList.remove('qv-error');
        }
        if (q_source === 'quote_destino') {
            q_value.textContent = `(${e.currentTarget.textContent})`;
        }
        else {
            q_value.textContent = e.currentTarget.textContent;
        }
        let q_input = document.querySelectorAll('input[name="' + q_source + '"]')[0];
        q_input.value = e.currentTarget.getAttribute('data-value');
        let quote_data = [];
        quote_data[q_source] = e.currentTarget.getAttribute('data-value');
        this.quoteForm.patchValue(quote_data);
        if (q_source == 'months') {
            const quote_dates1 = new Date();
            const quote_dates2 = this.sumarDias(new Date(), parseInt(e.currentTarget.getAttribute('data-value')));
            this.quoteForm.patchValue({
                quote_dates1: quote_dates1,
                quote_dates2: quote_dates2,
            });
            this.quote_data.data.quote_date1 = quote_dates1.toString();
            this.quote_data.data.quote_date2 = quote_dates2.toString();
            this.quote_data.data.days = parseInt(e.currentTarget.getAttribute('data-value')) + 1;
            this.quote_data.passed.quote_dates1 = true;
            this.quote_data.passed.quote_dates2 = true;
        }
        if (q_source == 'paxAges') {
            this.quote_data.data.quote_paxs = e.currentTarget.getAttribute('data-value');
            this.quote_data.passed.paxAges = true;
        }
        if (q_source == 'quote_destino') {
            this.quote_data.data.quote_destino = e.currentTarget.getAttribute('data-value');
            this.quote_data.passed.quote_destino = true;
        }
    }
    initQuote() {
        // console.log(`Initializing: quote-model -> ${this.quote_settings.type}`);
        if (this.quote_settings.type == 'nomadcare') {
            const quote_data_container = document.querySelectorAll('.quote-data');
        }
    }
    getParamValueQueryString(paramName) {
        const url = window.location.href;
        let paramValue;
        if (url.includes('?')) {
            const httpParams = new HttpParams({ fromString: url.split('?')[1] });
            paramValue = httpParams.get(paramName);
        }
        return paramValue;
    }
    quote_dates() {
        const sd_val = $('input[name="sd_date"]').val();
        const ed_val = $('input[name="ed_date"]').val();
        let quote_total_days = $('.quote-dates-total');
        if (sd_val && ed_val) {
            this.quoteForm.patchValue({
                quote_dates1: this.getMonthDay(new Date(sd_val), 'f'),
                quote_dates2: this.getMonthDay(new Date(ed_val), 'f')
            });
            this.toggleModalQuote();
            this.quote_state.field_dates = false;
            this.quote_data.data.quote_date1 = sd_val;
            this.quote_data.data.quote_date2 = ed_val;
            this.quote_data.passed.quote_dates1 = true;
            this.quote_data.passed.quote_dates2 = true;
            const date1 = new Date(sd_val);
            const date2 = new Date(ed_val);
            const diffTime = Math.abs(date2.getTime() - date1.getTime());
            const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24));
            const totalDiffDays = diffDays + 1;
            const text_days = this.quote_settings['market'] == 'br' ? 'dias' : 'días';
            quote_total_days.text(`${totalDiffDays} ${text_days}`);
        }
    }
    setFormMessage(t, c) {
        this.pax_error_msg = true;
        const settings = {
            pax: {
                target: document.querySelector('.pax-error-msg'),
                error_codes: {
                    0: { text: '' },
                    1: { text: 'Ingrese al menos 1 pasajero', data_dt: 'quote_form_validation_msg_pax_empty_field' },
                    2: { text: 'Lamentablemente no disponemos de coberturas para mayores de 85 años', data_dt: 'quote_form_validation_msg_pax_age_limit' }
                }
            }
        };
        const msg_container = settings[t].target;
        const error_msg = settings[t].error_codes[c].text;
        msg_container.innerText = error_msg;
        msg_container.setAttribute('data-dt', settings[t].error_codes[c].data_dt);
        this.translator.refreshContent(this.data_content, 'quote');
    }
    paxAgeChange(e) {
        let searchValue = e.target.value;
        if (searchValue > 85) {
            this.setFormMessage('pax', 2);
        }
        else {
            this.setFormMessage('pax', 0);
        }
        let allinputs = document.querySelectorAll('input.pax-age');
        const x = Array.from(allinputs).filter(function (input) {
            return input.value >= '1';
        });
        let btn_submit = document.getElementById('quote_submit_paxs');
        if (x.length != 0) {
            btn_submit.disabled = false;
        }
        else {
            btn_submit.disabled = true;
        }
    }
    quote_paxs() {
        let allinputs = document.querySelectorAll('input.pax-age');
        let error_state = false;
        let myLength = allinputs.length;
        let input;
        let error_code;
        const arr = [];
        for (let i = 0; i < myLength; ++i) {
            input = allinputs[i];
            if (input.value > 0) {
                arr.push(input.value);
            }
            if (input.value > 85) {
                error_state = true;
                error_code = 2;
            }
        }
        if (arr.length === 0) {
            error_state = true;
            error_code = 1;
        }
        if (error_code) {
            this.setFormMessage('pax', error_code);
        }
        else {
            this.quote_data.data.quote_paxs = arr; //.toString();
            this.quote_data.passed.paxAges = true;
            this.pre_quote_pax_ages = arr;
            this.toggleModalQuote();
            this.quote_state.field_paxs = false;
            this.quoteForm.controls['paxAges'].setValue(arr.toString());
        }
    }
    remove_pax(e, i) {
        if (!e.currentTarget.classList.contains('off')) {
            e.currentTarget.parentNode.parentNode.classList.add('fade-out');
            const a = e.currentTarget.parentNode.parentNode;
            setTimeout(() => {
                // this.pre_quote_pax_ages.splice(i, 1);
                this.add_pax_btn = true;
                a.parentNode.remove();
            }, 450);
        }
        ;
    }
    add_pax() {
        if (this.pre_quote_pax_ages.length < 9) {
            this.pre_quote_pax_ages.push(0);
            if (this.pre_quote_pax_ages.length === 9) {
                this.add_pax_btn = false;
            }
        }
    }
    quote_destino(e) {
        if (typeof e.target.value === 'string') {
            // console.log('process inside');
            const val = parseInt(e.target.value);
            const txt = e.target.innerText;
            this.quoteForm.patchValue({
                quote_destino: txt
            });
            this.quote_data.data.quote_destino = val;
            this.quote_data.passed.quote_destino = true;
            this.toggleModalQuote();
            this.quote_state.field_dest = false;
        }
    }
    toggleModalQuote() {
        this.quote_modal = !this.quote_modal;
        if (this.quote_modal) {
            if (this.quote_settings.toggle_scroll) {
                document.body.style.top = `-${window.scrollY}px`;
                document.body.style.position = 'fixed';
            }
            $('.quote-overlay').show();
        }
        else {
            const scrollY = document.body.style.top;
            if (this.quote_settings.toggle_scroll) {
                document.body.style.position = '';
                document.body.style.top = '';
                window.scrollTo(0, parseInt(scrollY || '0') * -1);
            }
            $('.quote-overlay').hide();
        }
    }
    refresh_dest(a, e) {
        const mt_elem = document.querySelector('.a365-qh-mt');
        const destination_value = e.currentTarget.innerText;
        if (a === 'hover') {
            // this.quote_modal_data.titles['mt'] = x;
            mt_elem.innerText = destination_value;
        }
        if (a === 'out') {
            if (this.quote_data.data.quote_destino) {
                // const dest_number = this.quote_data.data.quote_destino;
                // let dest = this.quote_destinos.filter(function (dest) {
                //   return dest.val === dest_number;
                // });
                const t = $('.destino-container button');
                t.each(function (idx) {
                    if ($(this).hasClass('selected')) {
                        mt_elem.innerText = $(this).text();
                    }
                });
            }
            else {
                // this.quote_modal_data.titles['mt'] = 'Selecciona destino';
                this.translator.refreshContent(this.data_content, 'quote');
            }
        }
    }
    quote_start(e) {
        let field = e.currentTarget.id;
        let header_title;
        // if destination ON (auto destination pre selected)
        if (this.quote_settings.hasOwnProperty('destination')) {
            // console.log('destination active');
            if (this.quote_settings.destination.hasOwnProperty('value') && field == 'field_dest') {
                if (this.quote_settings.destination.value > 0) {
                    return false;
                }
            }
        }
        this.toggleModalQuote();
        if (field === 'field_dates2' || field === 'field_dates') {
            field = 'field_dates';
            header_title = "Selecciona fechas";
        }
        // reset all states to false
        for (const [key, value] of Object.entries(this.quote_state)) {
            this.quote_state[key] = false;
        }
        /*
            PAXS
        */
        if (field === 'field_paxs') {
            if (this.quote_data.data.quote_paxs.length >= 1) {
                this.pre_quote_pax_ages = this.quote_data.data.quote_paxs;
            }
            else {
                this.pre_quote_pax_ages = [0, 0];
            }
            header_title = 'Completa las edades';
            this.quote_submit_paxs = this.quote_data.data.quote_paxs.length >= 1 ? false : true;
        }
        // set active quote field
        this.quote_state[field] = true;
        if (field === 'field_dates') {
            setTimeout(() => {
                this.generateCalendar();
            }, 0);
        }
        if (field === 'field_dest') {
            if (this.quote_data.data.quote_destino) {
                setTimeout(() => {
                    $('button[value="' + this.quote_data.data.quote_destino + '"]')
                        .addClass('selected');
                }, 0);
                const dest_number = this.quote_data.data.quote_destino;
                let dest = this.quote_destinos.filter(function (dest) {
                    return dest.val === dest_number;
                });
            }
        }
        var checkExist = setInterval(function () {
            if ($('#quote-modal').length) {
                $('#quote-modal').hide().addClass('modal-open ' + field).show();
                clearInterval(checkExist);
            }
        }, 100);
        const titles = {
            'field_dest': 'Tu cobertura para',
            'field_paxs': 'Quienes viajan',
            'field_dates': '',
        };
        this.quote_dialog_title = titles[field];
        this.quote_modal_data = {
            titles: { pt: titles[field], mt: header_title, pt_data_dt: field + '_pt', mt_data_dt: field + '_mt' }
        };
        if (field === 'field_paxs') {
            setTimeout(() => {
                this.paxs_age_input.first.nativeElement.focus();
            }, 200);
        }
    }
    paxAgeBlurInput(e) {
        e.currentTarget.parentNode.classList.remove('active');
    }
    paxAgeSetInput(e) {
        e.currentTarget.parentNode.classList.add('active');
    }
    getQuoteValidationErrors() {
        let ValidationErrors = [];
        const error_codes = {
            quote_destino: 'Selecciona destino',
            quote_dates1: 'Selecciona',
            quote_dates2: 'Selecciona',
            paxAges: 'Dato requerido'
        };
        // quote_form_error_msg_select
        Object.keys(this.quoteForm.controls).forEach(key => {
            const controlErrors = this.quoteForm.get(key).errors;
            if (controlErrors != null) {
                Object.keys(controlErrors).forEach(keyError => {
                    ValidationErrors.push(key);
                    let field = document.getElementsByName(key)[0];
                    field.placeholder = error_codes[key];
                    field.setAttribute('data-dt', 'quote_form_validation_msg_' + key);
                    this.quote_data.passed[key] = false;
                });
                this.translator.refreshContent(this.data_content, 'quote');
            }
        });
        return ValidationErrors;
    }
    gotoProducts() {
        const to = window.localStorage.getItem('to');
        const month = window.localStorage.getItem('month');
        const days = window.localStorage.getItem('days');
        const date_from = window.localStorage.getItem('date_from');
        const date_to = window.localStorage.getItem('date_to');
        const input_age = window.localStorage.getItem('input_age');
        const auxQuery = `to=${to}&month=${month}&date_from=${date_from}&date_to=${date_to}&input_age=${input_age}&quote_type=default`;
        const pQuery = window.localStorage.getItem('pQuery');
        let query = `${pQuery}&market=br&${auxQuery}&lang=pt`;
        window.location.href = `https://assist-365.com/productos${query}`;
    }
    // submit quote
    quote() {
        // console.log('quote');
        this.quote_data['qtype'] = this.quote_settings.type;
        if (this.quoteForm.valid) {
            if (this.quote_settings.mode === 'b2b') {
                this.dialogB2B();
            }
            else {
                this.quoteService.quote(this.quote_data);
                if (this.quote_redirect === true) {
                    if (this.quote_settings.type != 'auto') {
                        window.localStorage.setItem('quote_type', this.quote_settings.type);
                        if (this.quote_settings.hasOwnProperty('destination')) {
                            if (this.quote_settings.destination.value > 0) {
                                const data_landing = {
                                    label: this.quote_settings.destination.label,
                                    value: this.quote_settings.destination.value,
                                    product_id: this.quote_settings.destination.product_id,
                                };
                                window.localStorage.setItem('destination', JSON.stringify(data_landing));
                            }
                        }
                    }
                    if (this.quote_settings['market'] == 'br') {
                        // MODAL REDIRECT TO GLOBAL SITE
                        // this.modal_dialog_container = true;
                        if (this.origin_country == 155) {
                            window.location.href = "/produtos";
                        }
                        else {
                            // console.log('redirect');
                            this.gotoProducts();
                        }
                        //! WIP PRE
                        // window.location.href = "/produtos";
                    }
                    else {
                        // ***************************
                        // *   D E S T I N A T I O N 
                        // ***************************
                        if (this.quote_settings.hasOwnProperty('destination') && this.quote_settings.destination.value > 0) {
                            if (this.quote_settings.destination.hasOwnProperty('value') && this.quote_settings.destination.value > 0) {
                                const initialState = {
                                    title: 'Personaliza tu cobertura'
                                };
                                this.bsModalRef = this.modalService.show(PrecheckoutComponent, {
                                    initialState: initialState,
                                    animated: true,
                                    keyboard: false,
                                    backdrop: true,
                                    ignoreBackdropClick: true,
                                    class: 'modal-dialog-centered'
                                });
                                this.bsModalRef.content.closeBtnName = 'Seleccionar';
                                this.bsModalRef.content.action.subscribe((p) => {
                                    this.loaderService.loaderState(true);
                                    let urlProductQuery = window.localStorage.getItem('pQuery');
                                    this.quoteService.get('products' + urlProductQuery + '&provider=2').subscribe((data) => {
                                        if (data.length > 0) {
                                            let product = data.filter((function (p) {
                                                return p.product.name == 'WORLD COVER';
                                            }));
                                            let data_product = product[0]['product'];
                                            const formData = new FormData();
                                            const pax = window.localStorage.getItem('input_age');
                                            formData.append('name', window.localStorage.getItem('paxname'));
                                            formData.append('email', window.localStorage.getItem('paxemail'));
                                            formData.append('phone', window.localStorage.getItem('paxphone'));
                                            formData.append('to', window.localStorage.getItem('to'));
                                            formData.append('date_from', window.localStorage.getItem('date_from'));
                                            formData.append('date_to', window.localStorage.getItem('date_to'));
                                            formData.append('input_age', window.localStorage.getItem('input_age'));
                                            formData.append('input_total', '' + pax.split(',').length);
                                            formData.append('product_id', data_product.id);
                                            formData.append('total_price', data_product.total_price_back);
                                            formData.append('seller_id', window.localStorage.getItem('seller_id'));
                                            formData.append('entity_id', window.localStorage.getItem('entity_id'));
                                            formData.append('from', window.localStorage.getItem('country_id'));
                                            formData.append('country_code', window.localStorage.getItem('country_code'));
                                            // console.log('checkout-register');
                                            this.quoteService.post(formData, 'checkout-register').subscribe((data) => {
                                                if (data.status === true) {
                                                    this.loaderService.loaderState(false);
                                                    // console.log(data_product);
                                                    dataLayer.push({
                                                        'event': 'addToCart',
                                                        'ecommerce': {
                                                            'currencyCode': 'USD',
                                                            'add': {
                                                                'products': [{
                                                                        'name': data_product.name,
                                                                        'id': data_product.id,
                                                                        'price': data_product.total_price_usd,
                                                                        'brand': 'Assist-365',
                                                                        'category': 'B2C',
                                                                        'quantity': 1
                                                                    }]
                                                            }
                                                        }
                                                    });
                                                    // redirect to smartcheckout ----> smartcheckout
                                                    const checkout = `https://assist-365.com/smartcheckout/${data.id}`;
                                                    // const checkout = `/ar/smartcheckout/${data.id}`;
                                                    window.location.href = checkout;
                                                }
                                            });
                                            // console.log(product);
                                        }
                                    }, error => {
                                    });
                                });
                            }
                        }
                        else {
                            // redirect...
                            window.location.href = `${this.geo_url.substring(0, 2)}/productos`;
                        }
                    }
                }
                else {
                    // emitir quote a applist y muestre prods
                    this.emit_quote.emit(1);
                }
            }
        }
        else {
            if (this.quote_settings.type == 'default') {
                this.getQuoteValidationErrors();
            }
            if (this.quote_settings.type == 'nomadcare') {
                let q_inputs = document.getElementById('quote-container-nomadcare').querySelectorAll('input');
                for (let i = 0; i < q_inputs.length; i++) {
                    let status = q_inputs[i].value.length === 0 ? false : true;
                    const t = document.getElementsByClassName(`qv-${q_inputs[i].getAttribute('name')}`);
                    const e_label = t[0];
                    if (!status) {
                        e_label.classList.add('qv-error');
                        e_label.textContent = 'Seleccione';
                    }
                    else {
                        e_label.classList.contains('qv-error');
                        e_label.classList.remove('qv-error');
                    }
                }
            }
        }
    }
    setAttributes(el, attrs) {
        for (var key in attrs) {
            el.setAttribute(key, attrs[key]);
        }
    }
    getFeriados(m, y) {
        m = m + 1;
        const feriados = {
            10: {
                12: 'Día del Respeto a la diversidad cultural'
            },
            11: {
                23: 'Día de la Soberanía Nacional'
            },
            12: {
                7: 'Feriado puente con fines turísticos',
                8: 'Inmaculada Concepción de María',
                25: 'Navidad'
            }
        };
        if (feriados.hasOwnProperty(m)) {
            return feriados[m];
        }
        else {
            return false;
        }
    }
    setDataFromLocalStorage() {
        let cs = true;
        const quote_pre_data = {};
        const data_localStorage_valid_keys = {
            'default': ['date_from', 'date_to', 'to', 'input_age'],
            'nomadcare': ['days', 'input_age', 'to']
        };
        const localStorage_valid_keys = data_localStorage_valid_keys[this.quote_settings.type];
        Object.keys(localStorage_valid_keys).forEach(function (k) {
            if (window.localStorage.getItem(localStorage_valid_keys[k]) === null) {
                cs = false;
            }
            else {
                quote_pre_data[localStorage_valid_keys[k]] = window.localStorage.getItem(localStorage_valid_keys[k]);
            }
        });
        // IF CheckPass is TRUE Get data from prev quotation (NOT from origin home/landing)
        if (cs === true && Object.keys(quote_pre_data).length === localStorage_valid_keys.length && this.quote_settings['get_from_localstorage'] === true) {
            // console.warn('from localstorage....');
            /* ------------------------------
                    NOMADCARE MODE (type)
            --------------------------------- */
            if (this.quote_settings.type == 'nomadcare') {
                // PAX AGE ----------------------------------------------
                const input_age = quote_pre_data['input_age'];
                const btn_paxAges = document.querySelector("[data-value='" + input_age + "']");
                btn_paxAges.classList.add('active');
                document.getElementsByClassName('qv-paxAges')[0].textContent = btn_paxAges.textContent;
                document.querySelectorAll('input[name="paxAges"]')[0].value = input_age;
                this.quote_data.data.quote_paxs = [input_age];
                this.quote_data.passed.paxAges = true;
                let quote_data = [];
                quote_data['paxAges'] = btn_paxAges.textContent;
                this.quoteForm.patchValue(quote_data);
                // QUOTE TIME --------------------------------------------
                const days = quote_pre_data['days'] - 1;
                const btn_months = document.querySelector("[data-value='" + days + "']");
                btn_months.classList.add('active');
                document.getElementsByClassName('qv-months')[0].textContent = btn_months.textContent;
                document.querySelectorAll('input[name="months"]')[0].value = days.toString();
                const quote_dates1 = window.localStorage.getItem('date_from');
                const quote_dates2 = window.localStorage.getItem('date_to');
                this.quoteForm.patchValue({
                    quote_dates1: quote_dates1,
                    quote_dates2: quote_dates2,
                });
                this.quote_data.data.quote_date1 = quote_dates1.toString();
                this.quote_data.data.quote_date2 = quote_dates2.toString();
                // for nomadCare
                this.quote_data.data.days = days + 1;
                this.quote_data.passed.quote_dates1 = true;
                this.quote_data.passed.quote_dates2 = true;
                // DESTINO  ----------------------------------------------
                const to = quote_pre_data['to'].toString();
                const btn_to = document.querySelector("[data-value='" + to + "']");
                btn_to.classList.add('active');
                document.getElementsByClassName('qv-quote_destino')[0].textContent = `(${btn_to.textContent})`;
                document.querySelectorAll('input[name="quote_destino"]')[0].value = to;
                this.quoteForm.patchValue({ quote_destino: to });
                this.quote_data.data.quote_destino = to;
                this.quote_data.passed.quote_destino = true;
            }
            /* ------------------------------
                DEFAULT MODE (type)
            --------------------------------- */
            if (this.quote_settings.type == 'default') {
                const paxs = quote_pre_data['input_age'].split(',');
                // set paxs
                this.quote_data.data.quote_paxs = paxs;
                this.quote_data.passed.paxAges = true;
                this.quoteForm.controls['paxAges'].setValue(paxs.toString());
                // set destino
                let to = parseInt(quote_pre_data['to']);
                let to_text;
                this.quote_destinos.forEach(element => {
                    if (element.val === to) {
                        to_text = element.name;
                    }
                });
                if (this.dates_data_content.length != 0) {
                    // get destination translated
                    this.dates_data_content.filter(elem => {
                        let data_dt = 'quote_data_dest_' + to;
                        if (elem.area === data_dt) {
                            to_text = elem.text;
                        }
                    });
                }
                this.quoteForm.patchValue({
                    quote_destino: to_text
                });
                this.quote_data.data.quote_destino = to;
                this.quote_data.passed.quote_destino = true;
                // set dates
                const sd_val = quote_pre_data['date_from'];
                const ed_val = quote_pre_data['date_to'];
                let quote_total_days = $('.quote-dates-total');
                this.quoteForm.patchValue({
                    quote_dates1: this.getMonthDay(new Date(sd_val), 'f'),
                    quote_dates2: this.getMonthDay(new Date(ed_val), 'f')
                });
                Object.assign(this.quote_data.data, { quote_date1: sd_val, quote_date2: ed_val });
                Object.assign(this.quote_data.passed, { quote_dates1: true, quote_dates2: true });
                const date1 = new Date(sd_val);
                const date2 = new Date(ed_val);
                const diffTime = Math.abs(date2.getTime() - date1.getTime());
                const diffDays = Math.ceil(diffTime / (1000 * 60 * 60 * 24));
                const totalDiffDays = diffDays + 1;
                // console.log(date1);
                // console.log(date2);
                // console.log(diffTime);
                // console.log(diffDays);
                // console.log(totalDiffDays);
                const text_days = this.quote_settings['market'] == 'br' ? 'dias' : 'días';
                quote_total_days.text(`${totalDiffDays} ${text_days}`);
            }
        }
    }
    ngAfterViewInit() {
        let content_language = 'auto';
        if (window.location.search.length != 0) {
            const language = {
                'br': 155
            };
            if (language.hasOwnProperty(this.external_source_data.get('market'))) {
                content_language = language[this.external_source_data.get('market')];
            }
        }
        else {
            content_language = this.quote_settings.language;
            if (content_language != 'auto') {
                content_language = parseInt(content_language);
            }
        }
        content_language = 155;
        setTimeout((_) => this.translator.getContent(content_language, 'quote').subscribe((data) => {
            this.data_content = data;
        }, (error) => { console.error('error!'); }));
        setTimeout((_) => this.translator.getContent(content_language, 'quote_data').subscribe(data => {
            this.dates_data_content = data;
            this.setDataFromLocalStorage();
        }, error => { console.error('error!'); }));
    }
}
QuoteComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-quote',
                template: "<app-a365loader></app-a365loader>\n<div class=\"quote-overlay\"></div>\n\n<div *ngIf=\"modal_dialog_container\" id=\"modal-dialog-container\">\n    <div class=\"mdn-container\">\n        <div class=\"mdn-body\">\n            <p>\n                Nosso site local no Brasil e os produtos est\u00E3o em constru\u00E7\u00E3o. Enquanto isso, voc\u00EA\n                pode comprar nosso seguro internacional na ASSIST 365.\n            </p>\n        </div>\n        <div class=\"mdn-footer\">\n            <button (click)=\"gotoProducts()\" class=\"btn-core-1 btn-fx btn-pax-done\">Aceitar</button>\n        </div>\n    </div>\n</div>\n\n<div id=\"loader-quote\">\n    <div *ngIf=\"quote_modal\" id=\"quote-modal\" class=\"text-center\">\n        <div class=\"a365-quote-header\">\n            <span [attr.data-dt]=\"'quote_modal_title_' + quote_modal_data.titles.pt_data_dt\"\n                id=\"quote_modal_header_title\" class=\"a365-qh-pt\">{{quote_modal_data.titles.pt }}</span>\n            <span [attr.data-dt]=\"'quote_modal_title_' + quote_modal_data.titles.mt_data_dt\"\n                class=\"a365-qh-mt\">{{quote_modal_data.titles.mt}}</span>\n            <div *ngIf=\"quote_state.field_dates\" class=\"date-selector-info\">\n                <div class=\"di block-active\">\n                    <span data-dt=\"quote_dates_modal_header_date_start\">Fecha de inicio</span>\n                    <span>-</span>\n                </div>\n                <div class=\"de\">\n                    <span data-dt=\"quote_dates_modal_header_date_end\">Fecha de fin</span>\n                    <span>-</span>\n                </div>\n            </div>\n            <button (click)=\"toggleModalQuote()\" type=\"button\">&times;</button>\n        </div>\n        <div class=\"quote-body\">\n            <div #dyn_data_quote_dates *ngIf=\"quote_state.field_dates\">\n                <div class=\"calendar-container\">\n                    <input type=\"hidden\" name=\"sd_date\">\n                    <input type=\"hidden\" name=\"ed_date\">\n                    <div class=\"calendar-body\">\n                    </div>\n                    <div class=\"calendar-footer\">\n                        <div class=\"calendar-footer-container\">\n                            <div class=\"quote-msg-wrapper\">\n                                <img src=\"/home/assets/img/quote/ico_quote_calendar.svg\" alt=\"\">\n                                <span class=\"quote-msg-container\"></span><span\n                                    data-dt=\"quote_dates_modal_days_text\">D\u00EDas</span>\n                            </div>\n                            <div *ngIf=\"quote_settings.annual365\" class=\"quote-365-container\">\n                                <div data-dt=\"quote_dates_modal_footer_365days_text\" class=\"label\">Anual 365 d\u00EDas</div>\n                                <label class=\"switch\">\n                                    <input id=\"selection-mode\" type=\"checkbox\" disabled>\n                                    <span class=\"slider round\"></span>\n                                </label>\n                            </div>\n                        </div>\n                        <div class=\"calendar-footer-container p-0\">\n                            <button data-dt=\"quote_dates_modal_btn_cancel\" (click)=\"toggleModalQuote()\" type=\"button\"\n                                class=\"btn-core-default btn-fx\">\n                                Cancelar\n                            </button>\n                            <button data-dt=\"quote_dates_modal_btn_confirm\" class=\"calendar-footer-btn btn-fx\"\n                                id=\"quote_submit_dates\" type=\"button\" (click)=\"quote_dates()\"\n                                type=\"button\">Seleccionar</button>\n                        </div>\n                    </div>\n                </div>\n            </div>\n            <div #dyn_data_quote_destination *ngIf=\"quote_state.field_dest\">\n                <div (click)=\"quote_destino($event)\" class=\"destino-container\">\n                    <button [attr.data-dt]=\"'quote_destination_' + qd.destination_code\"\n                        (mouseover)=\"refresh_dest('hover',$event)\" (mouseout)=\"refresh_dest('out',$event)\"\n                        *ngFor=\"let qd of quote_destinos; let i = index\" type=\"button\" value=\"{{qd.val}}\">\n                        {{qd.name}}\n                    </button>\n                </div>\n            </div>\n            <div #dyn_data_quote_paxs *ngIf=\"quote_state.field_paxs\" class=\"paxs-container\">\n                <div class=\"block-container\">\n                    <form class=\"form-group mt-4\">\n                        <div class=\"row\">\n                            <div class=\"col-12\">\n                                <div class=\"row\">\n                                    <ng-template ngFor let-pax [ngForOf]=\"pre_quote_pax_ages\" let-i=\"index\">\n                                        <div class=\"col-4 col-md-lg-3\">\n                                            <div class=\"input-group\">\n                                                <input #paxs_age_input data-dt=\"quote_paxs_modal_input_age\"\n                                                    [value]=\"pax != 0 ? pax:''\" (blur)=\"paxAgeBlurInput($event)\"\n                                                    (focus)=\"paxAgeSetInput($event)\" (input)=\"paxAgeChange($event)\"\n                                                    type=\"number\" class=\"form-control pax-age\" placeholder=\"Edad\"\n                                                    min=\"1\" max=\"85\" maxlength=\"2\" minlength=\"1\">\n                                                <div class=\"input-group-append\">\n                                                    <button (click)=\"remove_pax($event,i)\"\n                                                        [ngClass]=\"{ 'off' : i === 0 }\" class=\"remove-pax\"\n                                                        type=\"button\">\n                                                        <i [ngClass]=\"{ 'off' : i === 0 }\" class=\"fa fa-times\"></i>\n                                                    </button>\n                                                </div>\n                                            </div>\n                                        </div>\n                                    </ng-template>\n                                    <div class=\"col-4 col-md-lg-3 text-left\">\n                                        <button *ngIf=\"add_pax_btn\" (click)=\"add_pax()\" class=\"add-new-pax\"\n                                            type=\"button\">+</button>\n                                    </div>\n                                </div>\n                            </div>\n                            <span class=\"pax-error-msg text-danger\"></span>\n                        </div>\n                    </form>\n                </div>\n                <div class=\"quote-modal-footer\">\n                    <button data-dt=\"quote_modal_paxs_btn_close\" (click)=\"toggleModalQuote()\"\n                        class=\"btn-core-default btn-fx btn-pax-done\">Cerrar</button>\n                    <button data-dt=\"quote_modal_paxs_btn_confirm\" (click)=\"quote_paxs()\" [disabled]=\"quote_submit_paxs\"\n                        id=\"quote_submit_paxs\" class=\"btn-core-1 btn-fx btn-pax-done\">Aceptar</button>\n                </div>\n            </div>\n            <!-- MARKET BT MODAL  -->\n        </div>\n    </div>\n\n    <div id=\"quote-container\">\n        <div *ngIf=\"quote_title\" class=\"quote-header\">\n            <div class=\"row\">\n                <div class=\"col-12\">\n                    <div class=\"loader-placeholder\">\n                        <div class=\"loader-animation loader-text\"></div>\n                        <span data-dt=\"quote_claim\">{{ quote_title }}</span>\n                    </div>\n                </div>\n            </div>\n        </div>\n        <div class=\"quote-body\">\n            <form [formGroup]=\"quoteForm\" (ngSubmit)=\"quote()\" aria-labelledby=\"Dir\" autocomplete=\"off\" novalidate>\n                <ng-container>\n                    <div class=\"row\">\n                        <div class=\"col-12\" [ngClass]=\"{'col-lg-3' : quote_mode === 'default', 'mb-0' : quote_mode === 'compact', 'mb-md-3' : quote_mode === 'compact'}\">\n                            <div class=\"quote-block\">\n                                <div class=\"loader-placeholder\">\n                                    <div class=\"loader-animation loader-text\"></div>\n                                    <label data-dt=\"quote_date_to\" for=\"field_dest\">Destino</label>\n                                </div>\n                                <div class=\"loader-placeholder\">\n                                    <div class=\"loader-animation loader-text\"></div>\n                                    <div class=\"input-icon\">\n                                        <input data-dt=\"quote_modal_title_field_dest_pt\"\n                                            [ngClass]=\"{'error-input': !quote_data.passed.quote_destino}\"\n                                            (click)=\"quote_start($event)\" id=\"field_dest\"\n                                            formControlName=\"quote_destino\" type=\"text\" class=\"form-control\"\n                                            name=\"quote_destino\" placeholder=\"Tu cobertura para\" readonly value=\"\">\n                                        <!-- <i [ngClass]=\"(quote_data.passed.quote_destino)?'fa-chevron-down':'fa-check'\"\n                                            class=\"fa\"></i> -->\n                                        <img src=\"https://assist-365.com.br/home/assets/img/quote/ico_quote_map_pin.svg\" alt=\"\">\n                                    </div>\n                                </div>\n                            </div>\n                        </div>\n                        <div class=\"col-12\"\n                        [ngClass]=\"{'col-lg-4' : quote_mode === 'default', 'mb-0' : quote_mode === 'compact', 'mb-md-3' : quote_mode === 'compact' }\"\n                        >\n                            <div class=\"quote-block\">\n                                <div class=\"row\">\n                                    <div class=\"col-6\">\n                                        <div class=\"loader-placeholder\">\n                                            <div class=\"loader-animation loader-text\"></div>\n                                            <label data-dt=\"quote_dates\" for=\"quote_dates1\">Fechas</label>\n                                        </div>\n                                        <div class=\"loader-placeholder\">\n                                            <div class=\"loader-animation loader-text\"></div>\n                                            <div class=\"input-icon\">\n                                                <input data-dt=\"quote_dates.input_date_from\"\n                                                    [ngClass]=\"{'error-input': !quote_data.passed.quote_dates1}\"\n                                                    (click)=\"quote_start($event)\" name=\"quote_dates1\"\n                                                    formControlName=\"quote_dates1\" type=\"text\" id=\"field_dates\"\n                                                    class=\"form-control\" placeholder=\"De inicio\" readonly>\n                                                <img src=\"https://assist-365.com.br/home/assets/img/quote/ico_quote_calendar.svg\" alt=\"\">\n                                                <!-- <i [ngClass]=\"(quote_data.passed.quote_destino)?'fa-chevron-down':'fa-check'\"\n                                                    class=\"fa\"></i> -->\n                                            </div>\n                                        </div>\n                                    </div>\n                                    <div class=\"col-6\">\n                                        <div class=\"loader-placeholder\">\n                                            <div class=\"loader-animation loader-text\"></div>\n                                            <label><span class=\"quote-dates-total\"></span></label>\n                                        </div>\n                                        <div class=\"loader-placeholder\">\n                                            <div class=\"loader-animation loader-text\"></div>\n                                            <div class=\"input-icon\">\n                                                <input data-dt=\"quote_dates.input_date_to\"\n                                                    [ngClass]=\"{'error-input': !quote_data.passed.quote_dates2}\"\n                                                    (click)=\"quote_start($event)\" name=\"quote_dates2\"\n                                                    formControlName=\"quote_dates2\" type=\"text\" id=\"field_dates2\"\n                                                    class=\"form-control\" placeholder=\"De fin\" readonly>\n                                                <img src=\"https://assist-365.com.br/home/assets/img/quote/ico_quote_calendar.svg\" alt=\"\">\n                                                <!-- <i [ngClass]=\"(quote_data.passed.quote_destino)?'fa-chevron-down':'fa-check'\"\n                                                    class=\"fa\"></i> -->\n                                            </div>\n                                        </div>\n                                    </div>\n                                </div>\n                            </div>\n                        </div>\n                        <div class=\"col-12\"\n                        [ngClass]=\"{'col-lg-2' : quote_mode === 'default', 'mb-0' : quote_mode === 'compact', 'mb-md-3' : quote_mode === 'compact'}\"\n                        >\n                            <div class=\"quote-block\">\n                                <div class=\"loader-placeholder\">\n                                    <div class=\"loader-animation loader-text\"></div>\n                                    <label [attr.data-dt]=\"quote_data.data.quote_paxs?.length > 1 ? 'quote_age' : 'quote_pax_age_ph'\" for=\"quote_dest\">Edades</label>\n                                </div>\n                                <div class=\"loader-placeholder\">\n                                    <div class=\"loader-animation loader-text\"></div>\n                                    <div class=\"input-icon\">\n                                        <input data-dt=\"quote_pax_age_ph\"\n                                            [ngClass]=\"{'error-input': !quote_data.passed.paxAges}\"\n                                            (click)=\"quote_start($event)\" name=\"paxAges\" type=\"text\" id=\"field_paxs\"\n                                            class=\"form-control\" placeholder=\"Edad\" readonly formControlName=\"paxAges\">\n                                        <img src=\"https://assist-365.com.br/home/assets/img/quote/ico_quote_paxs.svg\" alt=\"\">\n                                        <!-- <i [ngClass]=\"(quote_data.passed.quote_destino)?'fa-chevron-down':'fa-check'\" class=\"fa\"></i> -->\n                                    </div>\n                                </div>\n                            </div>\n                        </div>\n                        <div class=\"col-12 quote-button-container\"\n                        [ngClass]=\"{'col-lg-3': quote_mode === 'default', 'pl-md-3' : quote_mode === 'compact'}\"\n                        >\n                            <div class=\"loader-placeholder\">\n                                <div class=\"loader-animation loader-text\"></div>\n                                <button data-dt=\"quote_cta\" type=\"submit\" class=\"btn-core-1 btn-fx\">Cotizar</button>\n                            </div>\n                        </div>\n                    </div>\n                </ng-container>\n\n                <ng-container #quote_init *ngIf=\"quote_settings.start && quote_settings.type == 'nomadcare'\">\n                    <form [formGroup]=\"quoteForm\" (ngSubmit)=\"quote()\" aria-labelledby=\"Dir\" autocomplete=\"off\"\n                        novalidate>\n                        <div id=\"quote-container-nomadcare\" class=\"row no-gutters quote-container-nomadcare\">\n                            <div class=\"col-12 col-md-3\">\n                                <div class=\"quote-block\">\n                                    <div class=\"header-block\">\n                                        <div class=\"quote-label\">\n                                            <img src=\"/home/assets/img/quote/ico_pax.svg\" alt=\"\">\n                                            <span>Edad</span>\n                                        </div>\n                                        <div class=\"quote-value\"><span class=\"q_value qv-paxAges\">-</span>\n                                        </div>\n                                    </div>\n                                    <div class=\"body-block\">\n                                        <ul data-source=\"paxAges\" class=\"quote-data\">\n                                            <li><button type=\"button\" (click)=\"selectOpt($event)\"\n                                                    data-value=\"19\">18-39</button></li>\n                                            <li><button type=\"button\" (click)=\"selectOpt($event)\" data-value=\"41\"\n                                                    class=\"middle-btn\">40-49</button></li>\n                                            <li><button type=\"button\" (click)=\"selectOpt($event)\"\n                                                    data-value=\"51\">50-59</button></li>\n                                        </ul>\n                                    </div>\n                                    <input type=\"hidden\" name=\"paxAges\">\n                                </div>\n                            </div>\n                            <div class=\"col-12 col-md-3\">\n                                <div class=\"quote-block\">\n                                    <div class=\"header-block\">\n                                        <div class=\"quote-label\">\n                                            <img src=\"/home/assets/img/quote/ico_calendar.svg\" alt=\"\">\n                                            <span>Tiempo</span>\n                                        </div>\n                                        <div class=\"quote-value\">\n                                            <span class=\"q_value qv-months\">-</span>\n                                        </div>\n                                    </div>\n                                    <div class=\"body-block\">\n                                        <ul data-source=\"months\" class=\"quote-data\">\n                                            <li><button (click)=\"selectOpt($event)\" type=\"button\" data-value=\"179\">6\n                                                    meses</button></li>\n                                            <li><button (click)=\"selectOpt($event)\" type=\"button\" data-value=\"364\">12\n                                                    meses</button></li>\n                                        </ul>\n                                    </div>\n                                    <input type=\"hidden\" name=\"months\">\n                                </div>\n                            </div>\n                            <div class=\"col-12 col-md-4\">\n                                <div class=\"quote-block\">\n                                    <div class=\"header-block\">\n                                        <div class=\"quote-label\">\n                                            <img src=\"/home/assets/img/quote/ico_world.svg\" alt=\"\">\n                                            <span>Destino</span>\n                                        </div>\n                                        <div class=\"quote-value\">Mundial <span class=\"q_value qv-quote_destino\"></span>\n                                        </div>\n                                    </div>\n                                    <div class=\"body-block\">\n                                        <ul data-source=\"quote_destino\" class=\"quote-data\">\n                                            <li><button (click)=\"selectOpt($event)\" type=\"button\"\n                                                    data-value=\"17\">Incluye USA</button></li>\n                                            <li><button (click)=\"selectOpt($event)\" type=\"button\"\n                                                    data-value=\"18\">Excluye USA</button></li>\n                                        </ul>\n                                    </div>\n                                    <input type=\"hidden\" name=\"quote_destino\">\n                                </div>\n                            </div>\n                            <div class=\"col-12 col-md-2 text-center cta-container\">\n                                <button type=\"submit\" id=\"btn_cta_quote\" class=\"btn-quote\">Cotizar</button>\n                            </div>\n                        </div>\n                    </form>\n                </ng-container>\n\n            </form>\n        </div>\n    </div>\n</div>",
                styles: [".quote-overlay{background:rgba(0,0,0,.4);z-index:99998;display:none}#quote-modal,.quote-overlay{top:0;left:0;right:0;bottom:0;position:fixed}#quote-modal{user-select:none;-moz-user-select:none;-khtml-user-select:none;-webkit-user-select:none;-o-user-select:none;visibility:hidden;background:#fff;opacity:0;z-index:99999;border-radius:0;transition:opacity .3s,visibility .3s}#quote-modal.modal-open{visibility:visible;opacity:1}#quote-modal button{cursor:pointer;outline:0;box-shadow:none}#quote-modal .quote-body{background:#fff;height:calc(100% - 212px);color:#585858;overflow:auto;border-top:1px solid #fff}@media screen and (min-width:992px){#quote-modal .quote-body{height:100%}}#quote-modal .quote-header{background:#00698f;color:#fff;text-align:center;font-size:.9em;font-weight:600;height:113px;padding-top:.75rem;background:linear-gradient(45deg,#00698f 30%,#1ccdc9);border-bottom:1px solid #fff}#quote-modal .quote-header span{display:block}#quote-modal .quote-header button{position:absolute;z-index:9999;top:0;right:0;line-height:normal;background:none;border:0;outline:none;color:#fff;font-size:2em}@media screen and (min-width:992px){#quote-modal .quote-header .quote-header{height:171px}#quote-modal .quote-header button{top:-5px;color:#fff;font-size:2em}}#quote-modal .quote-body{padding:0}#quote-modal .quote-body span.error-msg{font-size:.8em}#quote-modal .quote-body .paxs-container{height:100%;display:flex;flex-direction:column;align-items:stretch;justify-content:space-between;padding:0;overflow:hidden}#quote-modal .quote-body .paxs-container .input-group{margin:.5rem 0;transition:opacity .5s ease,border-color .25s ease-in-out;border:1px solid #ced4da;border-radius:6px}#quote-modal .quote-body .paxs-container .input-group.active{border-color:#1ccdc9}#quote-modal .quote-body .paxs-container input.form-control{height:50px}#quote-modal .quote-body .paxs-container input.form-control:active,#quote-modal .quote-body .paxs-container input.form-control:focus,#quote-modal .quote-body .paxs-container input.form-control:hover{outline:none;box-shadow:none;border-color:#ced4da}#quote-modal .quote-body .paxs-container .pax-error-msg{font-size:.8em;display:block;padding:1rem}#quote-modal .quote-body .paxs-container .add-new-pax{height:50px;margin:10px 0;padding:0 1rem;background:none;border-radius:.25rem;border:1px solid #1ccdc9;color:#1ccdc9;font-size:1.4em;font-weight:600;text-transform:uppercase}#quote-modal .quote-body .paxs-container #add-pax-btn{display:flex;justify-content:center;align-items:center;flex-direction:column;border:0;outline:0;background:none;margin:auto}#quote-modal .quote-body .paxs-container #add-pax-btn img{margin-bottom:.5rem}#quote-modal .quote-body .paxs-container #add-pax-btn span{display:block;color:#1ccdc9;font-size:.9em}#quote-modal .quote-body .paxs-container button.add-pax{background:#1ccdc9;color:#fff;width:100%;border:0;border-radius:.25rem;height:50px}#quote-modal .quote-body .paxs-container button.add-pax i{font-size:.9em}#quote-modal .quote-body .paxs-container .input-group-append button.remove-pax{border:0;background:none;color:#585858;border-left:0;max-width:25px;border-radius:.25rem;transition:border-color .15s ease-in-out,box-shadow .15s ease-in-out}#quote-modal .quote-body .paxs-container .input-group-append button.remove-pax i{color:#ced4da;transition:color .25s ease}#quote-modal .quote-body .paxs-container .input-group-append button.remove-pax i:hover{color:#dc3545}#quote-modal .quote-body .paxs-container .input-group-append button.remove-pax.off i{color:#f2f2f2}#quote-modal .quote-body .paxs-container .input-group-append button.remove-pax:hover i{color:#dc3545}#quote-modal .quote-body .paxs-container .row{display:flex;align-items:center;justify-content:flex-start}#quote-modal .quote-body .paxs-container input.form-control{text-align:center;border:0;border-top-left-radius:6px;border-bottom-left-radius:6px}#quote-modal .quote-body .destino-container{padding:0}#quote-modal .quote-body .destino-container button{font-weight:500;font-size:.85em;color:#767676;text-decoration:none;transition:all .25s ease-in;padding:1.4rem;border:0;outline:none;box-shadow:none;border-bottom:2px solid #f0f0f0;display:block;width:100%;background:none}#quote-modal .quote-body .destino-container button.selected,#quote-modal .quote-body .destino-container button:active,#quote-modal .quote-body .destino-container button:hover{background:#1ccdc9;color:#fff}#quote-modal .quote-body .destino-container button:last-child{border-bottom:0}@media screen and (min-width:992px){#quote-modal .quote-body .destino-container button{padding:.9rem}}#quote-modal.field_dest{max-width:none}#quote-modal.field_paxs input.form-control{text-align:center;font-size:.8em}@media screen and (min-width:992px){#quote-modal{position:fixed;top:50%;left:50%;right:inherit;bottom:inherit;border-radius:6px;transform:translate(-50%,-50%)}#quote-modal.field_dest,#quote-modal.field_paxs{width:400px}#quote-modal.field_dest .quote-body{padding:1rem .5rem .5rem}#quote-modal.field_dates{height:540px;width:340px;width:640px}#quote-modal.field_dates :host ::ng-deep .calendar-container{min-height:100%}#quote-modal .quote-header{height:1rem;background:#fff}#quote-modal .quote-header span{display:none}#quote-modal .quote-body{padding:0}#quote-modal .quote-body .destino-container button{font-size:.8em}#quote-modal .quote-body .paxs-container{width:100%}#quote-modal .quote-body .paxs-container button.btn-pax-done{width:100%;margin:auto;border-radius:0;padding:1rem;transition:all .35s ease;font-size:.8em}}.btn-core-1,.btn-core-default,.calendar-footer-btn{height:100%;display:block;width:100%;border:0;outline:none;box-shadow:none;margin:auto;font-family:Montserrat,sans-serif!important;padding:1.15em 1.5em;background:#1ccdc9;font-weight:600;color:#fff;transition:all .5s ease;border-radius:4px;text-transform:uppercase;font-size:.85em;text-decoration:none;border-radius:0}.btn-core-1,.btn-core-default{overflow:hidden;cursor:pointer}.btn-core-default{background:#f0f0f0;color:#787878}#quote-container{background:#fff;color:#585858;border-radius:6px}#quote-container .quote-block{margin-bottom:1.5rem}#quote-container .quote-header{color:#00698f;text-align:center;font-size:.75em;text-transform:uppercase;font-weight:700;padding:1rem 2rem;line-height:1.3}#quote-container .quote-body{text-align:left;padding:0 1rem}#quote-container .quote-body label{font-weight:600;color:#10cfc9;font-size:.65em;margin:0;text-transform:uppercase}#quote-container .quote-body .input-icon{position:relative;width:100%;display:block}#quote-container .quote-body .input-icon img{position:absolute;left:.1rem;top:.65rem;width:.95rem}#quote-container .quote-body .input-icon i{position:absolute;right:3px;bottom:.9rem;font-size:.55em;color:#cacaca}#quote-container .quote-body .input-icon input.form-control{cursor:pointer;border:0;border-radius:0;font-size:.8em;padding:0 0 0 1.7rem;height:2.4rem;border-bottom:1px solid #10cfc9;outline:none;box-shadow:none}#quote-container .quote-body .input-icon input.form-control .error-input{border-bottom-color:#dc3545}#quote-container .quote-body .input-icon .form-control[readonly]{background-color:#fff!important}#quote-container .quote-body .input-icon input.error-input{border-bottom-color:#dc3545}@media screen and (min-width:1025px){#quote-container .quote-body label{font-size:.7em;margin-bottom:.2rem}#quote-container .quote-body .input-icon input.form-control{font-size:.82em;border-width:2px}}@media screen and (min-width:1025px){#quote-container .quote-block{margin-bottom:0}#quote-container .quote-header{font-size:1.1em;padding:1.5rem}#quote-container .quote-header span{display:block}#quote-container .quote-button-container{padding-left:0}#quote-container .btn-core-1{font-size:.9em;padding:0;margin-top:24px;height:46px}}.cb-container{display:block;position:relative;padding:.2rem 2rem;color:#585858!important;margin-bottom:12px;cursor:pointer;-webkit-user-select:none;user-select:none;text-transform:none!important;font-weight:500!important;font-size:.65em!important}.cb-container input{position:absolute;opacity:0;cursor:pointer;height:0;width:0}.checkmark{position:absolute;top:0;left:0;height:20px;width:20px;background-color:#fafafa;border:1px solid #10cfc9;border-radius:2px}.cb-container:hover input~.checkmark{background-color:#fafafa}.cb-container input:checked~.checkmark{background-color:#10cfc9}.checkmark:after{content:\"\";position:absolute;display:none}.cb-container input:checked~.checkmark:after{display:block}.cb-container .checkmark:after{left:7px;top:3px;width:5px;height:10px;border:solid #fff;border-width:0 3px 3px 0;transform:rotate(45deg)}.bar-divisor-1{background:#00698f;width:100%;height:40px}input::-webkit-inner-spin-button,input::-webkit-outer-spin-button{-webkit-appearance:none!important;margin:0!important}input[type=number]{-moz-appearance:textfield!important}@media screen and (min-width:992px){.field_dates .calendar-container .calendar-header{top:0;height:110px;background:linear-gradient(-45deg,#00698f 60%,#1ccdc9)}}:host ::ng-deep .calendar-container{font-family:Rubik,sans-serif;margin-bottom:1rem;position:relative;top:0;left:0;right:0;bottom:0;width:100%}:host ::ng-deep .calendar-container .calendar-body{position:relative;z-index:101;padding-bottom:120px;display:flex;flex-wrap:wrap;justify-content:center}@media screen and (min-width:992px){:host ::ng-deep .calendar-container .calendar-body{top:0;padding:0;height:330px;overflow-y:auto;position:relative}}:host ::ng-deep .calendar-container .calendar-footer{position:fixed;z-index:102;background:#fafafa;height:60px;height:auto;left:0;right:0;bottom:0;width:100%;display:flex;flex-direction:column;justify-items:center}:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container{font-size:.8em;padding:.5rem 1rem;position:relative;font-weight:500;display:flex;margin-top:0;align-items:center;justify-content:space-between}:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container .quote-365-container{display:flex;align-items:center;justify-content:center}:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container .quote-365-container .label{margin-right:.5rem;font-family:Montserrat,sans-serif}:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container .quote-msg-wrapper{display:flex;align-items:center;justify-content:center}:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container .quote-msg-wrapper .quote-msg-container{font-size:1em;font-family:Montserrat,sans-serif;padding-right:.35rem}:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container .quote-msg-wrapper img{margin-right:.5rem}@media screen and (min-width:992px){:host ::ng-deep .calendar-container .calendar-footer .calendar-footer-container{margin-top:0;position:relative;width:100%;left:0;right:0;bottom:0}}:host ::ng-deep .calendar-container .calendar-footer button{margin:auto;padding:1rem;transition:all .35s ease;font-size:.9rem}:host ::ng-deep .calendar-container .calendar-footer button:disabled,:host ::ng-deep .calendar-container .calendar-footer button[disabled]{background:#ededed;color:#454545;cursor:not-allowed}:host ::ng-deep .calendar-container .calendar-footer .btns-container{display:flex;width:100%;flex-direction:row!important}:host ::ng-deep .calendar-container .calendar-header{z-index:102;position:fixed;width:100%;top:48px;left:0;right:0;text-align:left;background:none}:host ::ng-deep .calendar-container .calendar-header .ch-title{color:#fff;padding:1rem 0 .7rem;text-align:center;width:100%;display:block;font-size:1.25em;display:none}:host ::ng-deep .calendar-container .calendar-header div.title{display:flex;align-items:center;justify-content:space-between;align-self:center;flex-grow:1;padding:1rem;font-size:1.1em;font-weight:400}:host ::ng-deep .calendar-container .calendar-header div.title span{font-size:.7em}:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub{font-size:.75em;padding:.5rem 1rem;font-weight:500;background:#fff;display:flex;margin-top:5px;align-items:center;justify-content:space-between}:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub .quote-365-container{display:flex;align-items:center;justify-content:center}:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub .quote-365-container .label{margin-right:.5rem}:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub .quote-msg-wrapper{display:flex;align-items:center;justify-content:center}:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub .quote-msg-wrapper .quote-msg-container{font-size:1em;font-family:Rubik}:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub .quote-msg-wrapper img{margin-right:.5rem}@media screen and (min-width:992px){:host ::ng-deep .calendar-container .calendar-header .calendar-header-sub{margin-top:0;position:absolute;left:0;right:0;bottom:0}}@media screen and (min-width:992px){:host ::ng-deep .calendar-container .calendar-header .ch-title{display:block}}:host ::ng-deep .calendar-container table{border-collapse:collapse;table-layout:fixed;width:100%}:host ::ng-deep .calendar-container table thead tr{background:#fcfcfc}:host ::ng-deep .calendar-container table thead th{padding:1.2rem 0;text-align:center;text-transform:uppercase;font-size:.65em;font-weight:500;border:1px solid #fafafa}:host ::ng-deep .calendar-container table tbody tr td{text-align:center;vertical-align:middle;font-size:.7em;font-family:Noto Sans,sans-serif;color:#444}:host ::ng-deep .calendar-container table tbody tr td>div{padding:1.25rem;align-items:center;justify-content:center;display:flex;border-radius:50%;width:35px;height:35px;margin:auto}:host ::ng-deep .calendar-container table tbody tr td>div:hover{background:#f4f4f4}:host ::ng-deep .calendar-container table tbody tr td.selectable{cursor:pointer}:host ::ng-deep .calendar-container table tbody tr td:not(.selectable){color:#bbb;cursor:not-allowed}:host ::ng-deep .calendar-container table tbody tr td .disabled,:host ::ng-deep .calendar-container table tbody tr td.selectable.disabled{color:#bbb}:host ::ng-deep .calendar-container table tbody tr td.current-day{color:#444}:host ::ng-deep .calendar-container table tbody tr td.current-day div{border-radius:50%;width:35px;height:35px;margin:auto;background:#f4f4f4}:host ::ng-deep .calendar-container table tbody tr td.date-range-start,:host ::ng-deep .calendar-container table tbody tr td.date-selected{color:#fff}:host ::ng-deep .calendar-container table tbody tr td.date-range-start div{transition:transform .3s ease-in-out;transform:scale(1.1);background:#1ccdc9;border-radius:50%;width:35px;height:35px;margin:auto}:host ::ng-deep .calendar-container table tbody tr td.date-range-end{color:#fff}:host ::ng-deep .calendar-container table tbody tr td.date-range-end div{transition:transform .3s ease-in-out;transform:scale(1.2);background:#1ccdc9;border-radius:50%;width:35px;height:35px;margin:auto}:host ::ng-deep .calendar-container table tbody tr td.date-range{background:rgba(28,205,201,.05);border-radius:0}:host ::ng-deep .calendar-container table tbody tr td.range-start{background-image:linear-gradient(90deg,transparent 50%,rgba(28,205,201,.05) 0)}:host ::ng-deep .calendar-container table tbody tr td.range-end{background-image:linear-gradient(270deg,transparent 50%,rgba(28,205,201,.05) 0)}:host ::ng-deep .calendar-container div.calendar-month{margin:0;padding:.7rem;border-right:1px solid #efefef;transition:color .3s ease-in;width:100%;display:flex;flex-direction:column}:host ::ng-deep .calendar-container div.calendar-month:hover .header span{color:#1ccdc9}:host ::ng-deep .calendar-container div.calendar-month:nth-child(2n){border-right:0}:host ::ng-deep .calendar-container div.calendar-month.month-disabled{display:none}:host ::ng-deep .calendar-container div.calendar-month .header{padding:1rem .5rem;display:flex;justify-content:flex-start;align-items:center}:host ::ng-deep .calendar-container div.calendar-month .header span{font-weight:400;font-size:1em;display:inline-block;text-transform:capitalize;transition:all .15s ease-in}:host ::ng-deep .calendar-container div.calendar-month .header span:last-child{margin-left:.7rem;font-size:.9em;font-weight:300}@media screen and (min-width:992px){:host ::ng-deep .calendar-container div.calendar-month .header{padding:1rem .5rem 0}}.quote-365-container .switch{position:relative;display:inline-block;width:160px;height:26px;outline:none;margin:0;top:0;width:52px;height:28px}.quote-365-container .switch input{opacity:0;width:0;height:0}.quote-365-container .switch .slider{position:absolute;cursor:pointer;top:0;left:0;right:0;bottom:0;background-color:#f0f0f0;transition:.4s}.quote-365-container .switch .slider:before{position:absolute;content:\"\";height:20px;width:20px;top:4px;left:4px;background-color:#fff;transition:.4s}.quote-365-container .switch input:checked+.slider{background-color:#1ccdc9}.quote-365-container .switch input:disabled+.slider{background-color:#f0f0f0}.quote-365-container .switch input:checked+.slider+div.label{color:#fff}.quote-365-container .switch input:checked+.slider:before{transform:translateX(24px)}.quote-365-container .switch>.round{border-radius:30px}.quote-365-container .switch>.round:before{border-radius:50%}.quote-365-container .switch div.label{position:absolute;width:100%;height:100%;top:0;right:0;left:0;display:flex;align-items:center;justify-content:center;text-transform:uppercase;font-size:.65em;transition:color .25s ease;font-weight:500;color:#999}.quote-365-container .switch div.label.active{color:#fff;left:12px;justify-content:flex-start}.calendar-month-footer{border-top:1px dotted #ccc;padding-top:.5rem;margin:2rem 0}.calendar-month-footer .title-data{padding:1rem}.calendar-month-footer table.month-details tr td{padding-left:10px}.calendar-month-footer table.month-details tr td:first-child div{width:10px;height:10px;border-radius:50%;background:#fafafa;font-size:.8em;color:#bbb;font-family:Rubik,sans-serif;font-weight:400;display:flex;align-items:center;justify-content:center}.calendar-month-footer table.month-details tr td:last-child{padding-left:0;text-align:left}.calendar-month-footer table.month-details tr td:last-child div{font-family:Rubik,sans-serif;font-size:.8em;color:#999}#quote-modal .a365-quote-header{position:relative;max-height:110px;height:110px;display:flex;flex-direction:column;align-items:center;justify-content:center;background:linear-gradient(-45deg,#00698f 40%,#1ccdc9)}#quote-modal .a365-quote-header span.a365-qh-pt{text-transform:uppercase;color:#22f2e8;font-size:.65em;font-weight:500;letter-spacing:1px}#quote-modal .a365-quote-header span.a365-qh-mt{color:#fff;font-size:1.2em;font-size:1.4em;font-weight:500}#quote-modal .a365-quote-header button{position:absolute;top:0;right:.25rem;background:none;line-height:1;padding:0;border:0;outline:0;color:#fff;font-size:1.8em}#quote-modal .quote-modal-footer{display:flex;align-items:center;justify-content:center;position:absolute;left:0;right:0;bottom:0}#quote-modal .quote-modal-footer button{width:50%}#quote-modal .quote-modal-footer button:disabled,#quote-modal .quote-modal-footer button[disabled]{background:#ededed;color:#454545;cursor:not-allowed}@media screen and (min-width:992px){#quote-modal .quote-modal-footer{position:relative}}#quote-modal .block-container{padding:0 1rem}@keyframes modal_header_gradient{0%{background-position:0 50%}50%{background-position:100% 50%}to{background-position:0 50%}}.fade-out{opacity:0}.date-selector-info{display:flex;width:100%;padding-top:.5rem;justify-content:center}.date-selector-info .de,.date-selector-info .di{display:flex;flex-direction:column;align-items:center;justify-content:center;width:50%;text-align:center;margin:0 1px;color:#fff;border-radius:6px;line-height:normal;background:none}.date-selector-info .de span:first-child,.date-selector-info .di span:first-child{text-transform:uppercase;font-size:.65em;display:block}.date-selector-info .de span:last-child,.date-selector-info .di span:last-child{font-size:.8em;font-weight:500}.date-selector-info .de.block-active span,.date-selector-info .di.block-active span{color:#fff}.date-selector-info .de.active-label span:first-child,.date-selector-info .di.active-label span:first-child{color:#1ccdc9;padding-bottom:.2rem}@media screen and (min-width:992px){.date-selector-info .de span:first-child,.date-selector-info .di span:first-child{text-transform:uppercase;font-size:.6em;display:block}.date-selector-info .de span:last-child,.date-selector-info .di span:last-child{font-size:.85em;font-weight:500}}@media screen and (min-width:992px){.date-selector-info{height:56px;height:auto}.date-selector-info .de,.date-selector-info .di{background:none;border:0}.date-selector-info .de span:first-child,.date-selector-info .di span:first-child{color:#fff;font-weight:700}.date-selector-info .de span:last-child,.date-selector-info .di span:last-child{color:#fff}.date-selector-info .de.block-active,.date-selector-info .di.block-active{background:none;border:0}}.quote-container-nomadcare{font-family:Montserrat,sans-serif;text-align:left}.quote-container-nomadcare .cta-container{display:flex;align-items:flex-end;justify-content:center}.quote-container-nomadcare .cta-container button.btn-quote{width:100%;border:0;background:#1ccdc9;color:#fff;outline:0;font-size:.9em;padding:1rem;font-weight:600;text-transform:uppercase}.quote-container-nomadcare .cta-container button.btn-quote:hover{cursor:pointer}.quote-container-nomadcare .quote-block .qv-error{font-size:.65em;color:#dc3545}.quote-container-nomadcare .quote-block .header-block{display:flex;align-items:center;justify-content:space-between;padding:0}.quote-container-nomadcare .quote-block .header-block .quote-label,.quote-container-nomadcare .quote-block .header-block .quote-value{padding-bottom:.75rem;height:100%}.quote-container-nomadcare .quote-block .header-block .quote-label{border-bottom:1px solid #c2d9e2;display:flex;flex-grow:1;align-items:center;justify-content:flex-start;font-weight:700;text-transform:uppercase;font-size:.75rem;color:#00698f}.quote-container-nomadcare .quote-block .header-block .quote-label img{margin-right:.7rem}.quote-container-nomadcare .quote-block .header-block .quote-label span{padding-right:.5rem}.quote-container-nomadcare .quote-block .header-block .quote-value{font-size:.7em;font-weight:600;text-transform:uppercase;border-bottom:1px solid #1ccdc9;padding-left:.5rem;padding-right:.5rem;color:#1ccdc9}.quote-container-nomadcare .quote-block .body-block{padding:.5rem 0 0;display:flex;align-items:center;justify-content:center;margin-top:.5rem}.quote-container-nomadcare .quote-block .body-block ul{list-style:none;padding:0;margin:0;display:flex;align-items:center;justify-content:center;flex-direction:row;width:100%}.quote-container-nomadcare .quote-block .body-block ul li{width:100%;padding:0}.quote-container-nomadcare .quote-block .body-block ul li button{width:100%;outline:0;background:none;text-align:left;font-size:.8em;font-weight:500;color:#00698f;transition:all .3s ease;padding:1rem 0;text-align:center;background:rgba(232,250,250,.25);background:linear-gradient(180deg,#fff 40%,#eaeaea);border:1px solid #eee;transition:all .4s ease}.quote-container-nomadcare .quote-block .body-block ul li button:hover{background-color:#1ccdc9;color:#525252;cursor:pointer}.quote-container-nomadcare .quote-block .body-block ul li button.active{background:#e8fafa;background:#00698f;color:#828282;background:linear-gradient(0deg,#fff 40%,#eaeaea);transition:all .3 ease;box-shadow:inset 0 0 2px #c1c1c1;outline:none}#modal-dialog-container{position:fixed;top:0;right:0;z-index:99999;left:0;display:flex;align-items:center;justify-content:center;bottom:0;width:100%;background:rgba(0,0,0,.42)}#modal-dialog-container .mdn-container{font-family:Montserrat,sans-serif;width:420px;border-radius:6px;overflow:hidden;background:#fff}#modal-dialog-container .mdn-body{padding:1.6rem}#modal-dialog-container .mdn-body p{margin:0;padding:0;color:#585858}#modal-dialog-container .mdn-footer{padding:.5rem 0;border-top:1px solid #eee}#modal-dialog-container .mdn-footer button{width:auto;display:block;padding:.7rem 2rem;border-radius:4px}input.pax-age{padding:.375rem}"]
            },] }
];
QuoteComponent.ctorParameters = () => [
    { type: QuoteService },
    { type: FormBuilder },
    { type: Router },
    { type: TranslatorService },
    { type: BsModalService },
    { type: A365loaderService },
    { type: QuoteConfig }
];
QuoteComponent.propDecorators = {
    quote_mode: [{ type: Input }],
    label: [{ type: Input }],
    emit_quote: [{ type: Output }],
    paxs_age_input: [{ type: ViewChildren, args: ['paxs_age_input',] }],
    dyn_data_quote_destination: [{ type: ViewChild, args: ['dyn_data_quote_destination',] }],
    dyn_data_quote_dates: [{ type: ViewChild, args: ['dyn_data_quote_dates',] }],
    dyn_data_quote_paxs: [{ type: ViewChild, args: ['dyn_data_quote_paxs',] }],
    pax_age_input: [{ type: ViewChild, args: ['paxs_age_input',] }],
    quote_init: [{ type: ViewChild, args: ['quote_init',] }]
};

class QuoteModule {
    static forRoot(config) {
        return {
            ngModule: QuoteModule,
            providers: [
                { provide: QuoteConfig, useValue: config },
                QuoteService,
            ]
        };
    }
    static forChild() {
        return {
            ngModule: QuoteModule
        };
    }
}
QuoteModule.decorators = [
    { type: NgModule, args: [{
                declarations: [QuoteComponent, ExpressQuoteComponent, PrecheckoutComponent],
                exports: [QuoteComponent],
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    FormsModule,
                    HttpClientModule,
                    RouterModule.forRoot([]),
                    ModalModule.forRoot(),
                    A365loaderModule.forRoot(),
                ],
                providers: [
                    QuoteService,
                    TranslatorService,
                    BsModalService,
                    A365loaderService
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { QuoteComponent, QuoteModule, QuoteService, QuoteConfig as ɵa, ExpressQuoteComponent as ɵb, PrecheckoutComponent as ɵc };
//# sourceMappingURL=a365quote.js.map
